searchData={"items":[{"type":"task","title":"mix supabase.gen.auth","doc":"Generates authentication logic backed by Supabase and related views for `Phoenix`.\n\n    $ mix supabase.gen.auth MyAppWeb [options]","ref":"Mix.Tasks.Supabase.Gen.Auth.html"},{"type":"task","title":"LiveView vs conventional Controllers & Views - mix supabase.gen.auth","doc":"Authentication views can either be generated to use LiveView by passing\nthe `--live` option, or they can use conventional Phoenix\nControllers & Views by passing `--no-live` (default).\n\nUsing the `--live` option is advised if you plan on using LiveView\nelsewhere in your application. The user experience when navigating between\nLiveViews can be tightly controlled, allowing you to let your users navigate\nto authentication views without necessarily triggering a new HTTP request\neach time (which would result in a full page load).\n\n>","ref":"Mix.Tasks.Supabase.Gen.Auth.html#module-liveview-vs-conventional-controllers-views"},{"type":"task","title":"Warning - mix supabase.gen.auth","doc":">\n> This task relies on Phoenix CoreComponents and Phoenix templates for now, of course you can edit the generated files to fit your needs.","ref":"Mix.Tasks.Supabase.Gen.Auth.html#module-warning"},{"type":"task","title":"Strategies - mix supabase.gen.auth","doc":"The `--strategy` (`-s`) option can be used to specify the authentication strategy.\nThe default strategy is `password`. Also, multiple strategies can be used in the same application\nwith multiple `-s` options.\n\nThe available strategies are:\n\n* `password` - Email and password authentication.\n* `oauth` - OAuth authentication.\n* `anon` - Anonymous authentication.\n* `id_token` - ID token authentication.\n* `sso` - Single sign-on authentication.\n* `otp` - One-time password authentication.\n\nFor each strategy, a `log_in_with_ ` function will be generated in the `MyAppWeb.Auth` module, where `MyApp` is the name of your application.","ref":"Mix.Tasks.Supabase.Gen.Auth.html#module-strategies"},{"type":"task","title":"Example - mix supabase.gen.auth","doc":"$ mix supabase.gen.auth MyAppWeb --strategy password --strategy oauth","ref":"Mix.Tasks.Supabase.Gen.Auth.html#module-example"},{"type":"task","title":"Options - mix supabase.gen.auth","doc":"* `--live` - Generate LiveView authentication views.\n* `--no-live` - Generate conventional Phoenix Controllers & Views.\n* `--strategy` - The authentication strategy to use. Defaults to `password`.\n* `--client` - The Supabase self managed client to use for authentication.\n* `--supabase-url` - The Supabase URL in case to use one-off client. Check the [configuration](#configuration) section below.\n* `--supabase-key` - The Supabase API key in case to use one-off client. Check the [configuration](#configuration) section below.\n* `--auth-only` - Generate only the authentication module without views, controllers or routes.","ref":"Mix.Tasks.Supabase.Gen.Auth.html#module-options"},{"type":"task","title":"Configuration - mix supabase.gen.auth","doc":"To use this task, you need to have at least `supabase_potion` and `supabase_auth` packages installed in your project, and `phoenix_live_view` if you want to use LiveView or `phoenix` and `phoenix_plug` if you want to use conventional Controllers & (dead) Views.\n\nAlso, you need to tell the task which `Supabase` client to be used in the generated functions,\nfor that you have two available options following the [supabase-ex](https://hexdocs.pm/supabase_potion/readme.html#usage) docs","ref":"Mix.Tasks.Supabase.Gen.Auth.html#module-configuration"},{"type":"task","title":"Self-managed client - mix supabase.gen.auth","doc":"The best way is to define a self-managed `Supabase` client in your `config.exs` and app. You can follow the [documentation about it](https://hexdocs.pm/supabase_potion/Supabase.Client.html).\n\n    # lib/my_app/supabase.ex\n    defmodule MyApp.Supabase do\n      use Supabase.Client, otp_app: :my_app\n    end\n\n    # config/config.exs\n    import Config\n\n    config :my_app, MyApp.Supabase,\n      base_url: \"https:// .supabase.co\",\n      api_key: \" \",\n      # any additional optional params\n      access_token: \" \",\n      db: [schema: \"another\"],\n      auth: [debug: true] # optional\n\nThen you can invoke this task passing the basic options in addition to the `--client` option:\n\n    $ mix supabase.gen.auth MyAppWeb -s anon --client MyApp.Supabase\n\nThis is the best option if you are going to use the same client in other parts of your application and also to hold and handle authentication tokens for different scopes via `Supabase.Client.update_access_token/2`.","ref":"Mix.Tasks.Supabase.Gen.Auth.html#module-self-managed-client"},{"type":"task","title":"One-off client - mix supabase.gen.auth","doc":"If you don't want to define a self-managed client, you can pass the `--supabase-url` and `--supabase-key` options to the task:\n\n    $ mix supabase.gen.auth MyAppWeb -s anon --supabase-url https:// .supabase.co --supabase-key  \n\nThis option is useful if you are going to use the client only in the authentication logic and don't need to handle tokens for different scopes.","ref":"Mix.Tasks.Supabase.Gen.Auth.html#module-one-off-client"},{"type":"task","title":"Generated Files - mix supabase.gen.auth","doc":"","ref":"Mix.Tasks.Supabase.Gen.Auth.html#module-generated-files"},{"type":"task","title":"LiveView - mix supabase.gen.auth","doc":"* `lib/my_app_web/router.ex` - The authentication routes, modifies the existing one in-place.\n* `lib/my_app_web/user_auth.ex` - The authentication module.\n* `lib/my_app_web/controllers/session_controller.ex` - The session controller, with token handling.\n* `lib/my_app_web/live/login_live.ex` - The LiveView for the login page.\n* `lib/my_app_web/live/registration_live.ex` - The LiveView for the registration page.\n* `test/support/conn_case.exs` - The test helper for the authentication, modifies the existing one in-place.","ref":"Mix.Tasks.Supabase.Gen.Auth.html#module-liveview"},{"type":"task","title":"Non-LiveView (Traditional Phoenix Controllers & Views) - mix supabase.gen.auth","doc":"* `lib/my_app_web/router.ex` - The authentication routes, modifies the existing one in-place.\n* `lib/my_app_web/user_auth.ex` - The authentication module.\n* `lib/my_app_web/controllers/session_controller.ex` - The session controller, with token handling.\n* `lib/my_app_web/controllers/session_html.ex` - The session view, with the login form.\n* `lib/my_app_web/controllers/session_html/new.html.heex` - The login form.\n* `lib/my_app_web/controllers/registration_controller.ex` - The registration controller.\n* `lib/my_app_web/controllers/registration_html.ex` - The registration view.\n* `lib/my_app_web/controllers/registration_html/new.html.heex` - The registration form.\n* `test/support/conn_case.exs` - The test helper for the authentication, modifies the existing one in-place.","ref":"Mix.Tasks.Supabase.Gen.Auth.html#module-non-liveview-traditional-phoenix-controllers-views"},{"type":"module","title":"Supabase.Auth","doc":"The main interface for interacting with Supabase's Auth authentication service.\nThis module provides comprehensive functionality for user authentication, session management, \nand identity handling in Elixir applications.","ref":"Supabase.Auth.html"},{"type":"module","title":"Features - Supabase.Auth","doc":"* Multiple authentication methods: password, OAuth, OTP, SSO, and anonymous\n* Session management: creation, refresh, and validation\n* User management: registration, profile updates, and password recovery\n* Multi-factor authentication support\n* Identity linking/unlinking for social providers\n* Server health and settings information","ref":"Supabase.Auth.html#module-features"},{"type":"module","title":"Integration Options - Supabase.Auth","doc":"* **HTTP API client**: Core functions for direct API interaction\n* **Plug integration**: For traditional web applications (`Supabase.Auth.Plug`)\n* **Phoenix LiveView**: For real-time applications (`Supabase.Auth.LiveView`)","ref":"Supabase.Auth.html#module-integration-options"},{"type":"module","title":"Example Usage - Supabase.Auth","doc":"Basic authentication with email and password:\n\n    {:ok, session} = Supabase.Auth.sign_in_with_password(client, %{\n      email: \"user@example.com\",\n      password: \"secure-password\"\n    })\n\nRetrieve the current user:\n\n    {:ok, user} = Supabase.Auth.get_user(client, session)\n\nSee individual function documentation for more examples and options.\n\nFor comprehensive information about the Auth API, check the official documentation at:\nhttps://supabase.com/docs/reference/javascript/auth-api","ref":"Supabase.Auth.html#module-example-usage"},{"type":"function","title":"Supabase.Auth.exchange_code_for_session/4","doc":"Exchanges an authorization code for a session.\n\nUsed in the PKCE (Proof Key for Code Exchange) flow to convert an authorization code\ninto a valid session using a code_verifier that matches the previously sent code_challenge.","ref":"Supabase.Auth.html#exchange_code_for_session/4"},{"type":"function","title":"Parameters - Supabase.Auth.exchange_code_for_session/4","doc":"* `client` - The `Supabase` client to use for the request.\n  * `auth_code` - The authorization code received from the OAuth provider.\n  * `code_verifier` - The original code verifier that was used to generate the code challenge.\n  * `opts` - Additional options:\n    * `redirect_to` - The URL to redirect to after successful authentication.","ref":"Supabase.Auth.html#exchange_code_for_session/4-parameters"},{"type":"function","title":"Examples - Supabase.Auth.exchange_code_for_session/4","doc":"iex> auth_code = \"received_auth_code\"\n    iex> code_verifier = \"original_code_verifier\"\n    iex> Supabase.Auth.exchange_code_for_session(client, auth_code, code_verifier)\n    {:ok, %Supabase.Auth.Session{}}","ref":"Supabase.Auth.html#exchange_code_for_session/4-examples"},{"type":"function","title":"Supabase.Auth.get_auth_module!/0","doc":"Retrieves the auth module handle from the application configuration.\nCheck https://hexdocs.pm/supabase_auth/readme.html#usage","ref":"Supabase.Auth.html#get_auth_module!/0"},{"type":"function","title":"Supabase.Auth.get_server_health/1","doc":"Retrieves the server health from the Auth API.","ref":"Supabase.Auth.html#get_server_health/1"},{"type":"function","title":"Parameters - Supabase.Auth.get_server_health/1","doc":"- `client` - The `Supabase` client to use for the request.","ref":"Supabase.Auth.html#get_server_health/1-parameters"},{"type":"function","title":"Examples - Supabase.Auth.get_server_health/1","doc":"iex> Supabase.Auth.get_server_health(client)\n    {:ok, %Supabase.Auth.ServerHealth{}}","ref":"Supabase.Auth.html#get_server_health/1-examples"},{"type":"function","title":"Supabase.Auth.get_server_settings/1","doc":"Retrieves the server settings from the Auth API.","ref":"Supabase.Auth.html#get_server_settings/1"},{"type":"function","title":"Parameters - Supabase.Auth.get_server_settings/1","doc":"- `client` - The `Supabase` client to use for the request.","ref":"Supabase.Auth.html#get_server_settings/1-parameters"},{"type":"function","title":"Examples - Supabase.Auth.get_server_settings/1","doc":"iex> Supabase.Auth.get_server_settings(client)\n    {:ok, %Supabase.Auth.ServerSettings{}}","ref":"Supabase.Auth.html#get_server_settings/1-examples"},{"type":"function","title":"Supabase.Auth.get_user/2","doc":"Retrieves the currently authenticated user's profile.\n\nThis function makes an API request to get the most up-to-date user information\nassociated with the provided session. This is useful for checking the current\nstate of the user including verification status, metadata, and linked identities.","ref":"Supabase.Auth.html#get_user/2"},{"type":"function","title":"Parameters - Supabase.Auth.get_user/2","doc":"* `client` - The Supabase client to use for the request\n* `session` - An active session containing a valid access token","ref":"Supabase.Auth.html#get_user/2-parameters"},{"type":"function","title":"Returns - Supabase.Auth.get_user/2","doc":"* `{:ok, user}` - Successfully retrieved user profile\n* `{:error, error}` - Failed to retrieve user profile","ref":"Supabase.Auth.html#get_user/2-returns"},{"type":"function","title":"Examples - Supabase.Auth.get_user/2","doc":"iex> session = %Supabase.Auth.Session{access_token: \"eyJhbG...\"}\n    iex> {:ok, user} = Supabase.Auth.get_user(client, session)\n    iex> user.email\n    \"user@example.com\"\n    \n    # If the session is invalid or expired\n    iex> {:error, %Supabase.Error{code: :unauthorized}} = Supabase.Auth.get_user(client, invalid_session)","ref":"Supabase.Auth.html#get_user/2-examples"},{"type":"function","title":"Supabase.Auth.get_user_identities/2","doc":"Gets all identities for the authenticated user.","ref":"Supabase.Auth.html#get_user_identities/2"},{"type":"function","title":"Parameters - Supabase.Auth.get_user_identities/2","doc":"- `client` - The `Supabase` client to use for the request.\n  - `session` - The session to use for the request.","ref":"Supabase.Auth.html#get_user_identities/2-parameters"},{"type":"function","title":"Examples - Supabase.Auth.get_user_identities/2","doc":"iex> session = %Supabase.Auth.Session{access_token: \"example_token\"}\n    iex> Supabase.Auth.get_user_identities(client, session)\n    {:ok, [%Supabase.Auth.User.Identity{}, ...]}","ref":"Supabase.Auth.html#get_user_identities/2-examples"},{"type":"function","title":"Supabase.Auth.link_identity/3","doc":"Gets a URL to link a new identity to the authenticated user's account.","ref":"Supabase.Auth.html#link_identity/3"},{"type":"function","title":"Parameters - Supabase.Auth.link_identity/3","doc":"- `client` - The `Supabase` client to use for the request.\n  - `session` - The session to use for the request.\n  - `credentials` - The OAuth credentials to use for identity linking:\n     * `provider` - One of the supported OAuth providers (e.g., 'apple', 'azure', 'github', 'google', etc.)\n     * `options` - Optional parameters:\n       * `redirect_to` - URL to redirect the user after successful authentication\n       * `scopes` - List of OAuth scopes to request\n       * `query_params` - Additional query parameters to include in the OAuth URL\n       * `skip_browser_redirect` - Whether to skip redirecting the browser to the authorization URL","ref":"Supabase.Auth.html#link_identity/3-parameters"},{"type":"function","title":"Returns - Supabase.Auth.link_identity/3","doc":"- `{:ok, result}` - Successfully generated an identity linking URL, where result is a map containing:\n     * `provider` - The provider specified in the request\n     * `url` - The authorization URL to redirect to\n  - `{:error, error}` - Failed to generate an identity linking URL","ref":"Supabase.Auth.html#link_identity/3-returns"},{"type":"function","title":"Examples - Supabase.Auth.link_identity/3","doc":"iex> session = %Supabase.Auth.Session{access_token: \"example_token\"}\n    iex> credentials = %{provider: :github}\n    iex> Supabase.Auth.link_identity(client, session, credentials)\n    {:ok, %{provider: :github, url: \"https://...\"}}","ref":"Supabase.Auth.html#link_identity/3-examples"},{"type":"function","title":"Supabase.Auth.reauthenticate/2","doc":"Sends a reauthentication request for the authenticated user.\n\nThis method is typically used when performing sensitive operations that require \nrecent authentication. It sends a one-time password (OTP) to the user's email\nor phone number, which they need to verify to confirm their identity.","ref":"Supabase.Auth.html#reauthenticate/2"},{"type":"function","title":"Parameters - Supabase.Auth.reauthenticate/2","doc":"* `client` - The `Supabase` client to use for the request.\n  * `session` - The current user session containing the access token.","ref":"Supabase.Auth.html#reauthenticate/2-parameters"},{"type":"function","title":"Examples - Supabase.Auth.reauthenticate/2","doc":"iex> session = %Supabase.Auth.Session{access_token: \"example_token\"}\n    iex> Supabase.Auth.reauthenticate(client, session)\n    :ok","ref":"Supabase.Auth.html#reauthenticate/2-examples"},{"type":"function","title":"Supabase.Auth.refresh_session/2","doc":"Exchanges a refresh token for a new session.","ref":"Supabase.Auth.html#refresh_session/2"},{"type":"function","title":"Parameters - Supabase.Auth.refresh_session/2","doc":"- `client` - The `Supabase` client to use for the request.\n  - `refresh_token` - The refresh token to use for the request.","ref":"Supabase.Auth.html#refresh_session/2-parameters"},{"type":"function","title":"Examples - Supabase.Auth.refresh_session/2","doc":"iex> Supabase.Auth.refresh_session(client, \"refresh_token\")\n    {:ok, %Supabase.Auth.Session{}}","ref":"Supabase.Auth.html#refresh_session/2-examples"},{"type":"function","title":"Supabase.Auth.resend/3","doc":"Resends a signup confirm email for the given email address.","ref":"Supabase.Auth.html#resend/3"},{"type":"function","title":"Parameters - Supabase.Auth.resend/3","doc":"- `client` - The `Supabase` client to use for the request.\n  - `email` - A valid user email address to recover password\n  - `opts` - Options for the resend operation:\n    * `type` - The type of OTP to resend (`:sms`, `:signup`, `:phone_change`, `:email_change`)\n    * `options` - Additional options:\n      * `email_redirect_to` - The URL where the user should be redirected after confirming their email\n      * `captcha_token` - Token from a CAPTCHA verification if enabled","ref":"Supabase.Auth.html#resend/3-parameters"},{"type":"function","title":"Returns - Supabase.Auth.resend/3","doc":"- `:ok` - Successfully initiated resend operation\n  - `{:error, error}` - Failed to resend confirmation","ref":"Supabase.Auth.html#resend/3-returns"},{"type":"function","title":"Examples - Supabase.Auth.resend/3","doc":"iex> Supabase.Auth.resend(client, \"john@example.com\", %{type: :signup, options: %{email_redirect_to: \"http://localhost:4000/reset-pass\"}})\n  :ok","ref":"Supabase.Auth.html#resend/3-examples"},{"type":"function","title":"Supabase.Auth.reset_password_for_email/3","doc":"Sends a recovery password email for the given email address.","ref":"Supabase.Auth.html#reset_password_for_email/3"},{"type":"function","title":"Parameters - Supabase.Auth.reset_password_for_email/3","doc":"- `client` - The `Supabase` client to use for the request.\n  - `email` - A valid user email address to recover password\n  - `opts`:\n    - `redirect_to`: the url where the user should be redirected to reset their password\n    - `captcha_token`","ref":"Supabase.Auth.html#reset_password_for_email/3-parameters"},{"type":"function","title":"Examples - Supabase.Auth.reset_password_for_email/3","doc":"iex> Supabase.Auth.reset_password_for_email(client, \"john@example.com\", redirect_to: \"http://localohst:4000/reset-pass\")\n  :ok","ref":"Supabase.Auth.html#reset_password_for_email/3-examples"},{"type":"function","title":"Supabase.Auth.sign_in_anonymously/2","doc":"Signs in a user anonymously.\n\nThis method creates a new anonymous user in the Supabase auth system.\nAnonymous users can later be converted to permanent users by linking\nidentities or adding credentials.","ref":"Supabase.Auth.html#sign_in_anonymously/2"},{"type":"function","title":"Parameters - Supabase.Auth.sign_in_anonymously/2","doc":"- `client` - The `Supabase` client to use for the request.\n  - `opts` - Optional parameters for anonymous sign-in:\n    * `data` - Additional data to include with the sign-in request\n    * `captcha_token` - Verification token from CAPTCHA challenge","ref":"Supabase.Auth.html#sign_in_anonymously/2-parameters"},{"type":"function","title":"Returns - Supabase.Auth.sign_in_anonymously/2","doc":"- `{:ok, session}` - Successfully signed in anonymously, returns a session with tokens\n  - `{:error, error}` - Failed to sign in anonymously","ref":"Supabase.Auth.html#sign_in_anonymously/2-returns"},{"type":"function","title":"Examples - Supabase.Auth.sign_in_anonymously/2","doc":"iex> Supabase.Auth.sign_in_anonymously(client)\n    {:ok, %Supabase.Auth.Session{}}\n    \n    iex> Supabase.Auth.sign_in_anonymously(client, %{data: %{user_metadata: %{locale: \"en-US\"}}})\n    {:ok, %Supabase.Auth.Session{}}","ref":"Supabase.Auth.html#sign_in_anonymously/2-examples"},{"type":"function","title":"Supabase.Auth.sign_in_with_id_token/2","doc":"Signs in a user with ID token.\n\nThis method allows authentication using ID tokens issued by supported external providers like Google, Apple, Azure, etc. \nThe provider's ID token is verified and used to create or authenticate a user in the Supabase system.","ref":"Supabase.Auth.html#sign_in_with_id_token/2"},{"type":"function","title":"Parameters - Supabase.Auth.sign_in_with_id_token/2","doc":"- `client` - The `Supabase` client to use for the request.\n  - `credentials` - The credentials to use for the sign in:\n    * `provider` - Provider name identifying which provider should be used to verify the provided token (e.g., 'google', 'apple', 'azure', 'facebook', 'kakao')\n    * `token` - OIDC ID token issued by the specified provider\n    * `access_token` - Optional if the ID token contains an `at_hash` claim\n    * `nonce` - Optional if the ID token contains a `nonce` claim\n    * `options` - Optional parameters:\n      * `captcha_token` - Verification token from CAPTCHA challenge","ref":"Supabase.Auth.html#sign_in_with_id_token/2-parameters"},{"type":"function","title":"Returns - Supabase.Auth.sign_in_with_id_token/2","doc":"- `{:ok, session}` - Successfully authenticated with ID token, returns a valid session\n  - `{:error, error}` - Authentication failed","ref":"Supabase.Auth.html#sign_in_with_id_token/2-returns"},{"type":"function","title":"Examples - Supabase.Auth.sign_in_with_id_token/2","doc":"iex> credentials = %{\n    ...>   provider: \"google\", \n    ...>   token: \"eyJhbGciO...\" # ID token from Google\n    ...> }\n    iex> Supabase.Auth.sign_in_with_id_token(client, credentials)\n    {:ok, %Supabase.Auth.Session{}}","ref":"Supabase.Auth.html#sign_in_with_id_token/2-examples"},{"type":"function","title":"Supabase.Auth.sign_in_with_oauth/2","doc":"Signs in a user with OAuth.\n\nThis method initiates authentication with an OAuth provider (like GitHub, Google, etc.)\nand returns a URL to redirect the user to complete the authentication process.","ref":"Supabase.Auth.html#sign_in_with_oauth/2"},{"type":"function","title":"Parameters - Supabase.Auth.sign_in_with_oauth/2","doc":"- `client` - The `Supabase` client to use for the request.\n  - `credentials` - The credentials to use for the sign in:\n    * `provider` - One of the supported OAuth providers (e.g., 'apple', 'azure', 'bitbucket', 'discord', 'email', 'facebook', 'figma', 'github', 'gitlab', 'google', 'kakao', 'keycloak', 'linkedin', 'notion', 'phone', 'slack', 'spotify', 'twitch', 'twitter', 'workos', 'zoom', 'fly')\n    * `options` - Optional parameters:\n      * `redirect_to` - URL to redirect the user after successful authentication\n      * `scopes` - List of OAuth scopes to request\n      * `query_params` - Additional query parameters to include in the OAuth URL\n      * `skip_browser_redirect` - Whether to skip redirecting the browser to the authorization URL","ref":"Supabase.Auth.html#sign_in_with_oauth/2-parameters"},{"type":"function","title":"Returns - Supabase.Auth.sign_in_with_oauth/2","doc":"- `{:ok, data}` - Successfully generated OAuth URL; `data` contains the url for the redirection, the provider and the flow type. In case of a `PKCE` flow, it also contains the `code_verifier`, `code_challenge` and `code_challenge_method`.\n  - `{:error, error}` - Failed to generate OAuth URL","ref":"Supabase.Auth.html#sign_in_with_oauth/2-returns"},{"type":"function","title":"Examples - Supabase.Auth.sign_in_with_oauth/2","doc":"iex> credentials = %{\n    ...>   provider: :github,\n    ...>   options: %{\n    ...>     redirect_to: \"https://example.com/callback\"\n    ...>   }\n    ...> }\n    iex> Supabase.Auth.sign_in_with_oauth(client, credentials)\n    {:ok, %{provider: :github, url: \"https://auth.supabase.com/authorize?provider=github&...\", flow_type: :implicit}}","ref":"Supabase.Auth.html#sign_in_with_oauth/2-examples"},{"type":"function","title":"Supabase.Auth.sign_in_with_otp/2","doc":"Signs in a user with OTP (One-Time Password).\n\nThis method sends a one-time password to the user's email or phone number for authentication.\nThe user will need to verify this code to complete the authentication process using the\n`verify_otp/2` function.","ref":"Supabase.Auth.html#sign_in_with_otp/2"},{"type":"function","title":"Parameters - Supabase.Auth.sign_in_with_otp/2","doc":"- `client` - The `Supabase` client to use for the request.\n  - `credentials` - The credentials to use for the sign in:\n    * `email` - User's email address (required if phone not provided)\n    * `phone` - User's phone number (required if email not provided)\n    * `options` - Optional parameters:\n      * `data` - Additional data to include with the sign in request\n      * `email_redirect_to` - URL to redirect user after email verification\n      * `captcha_token` - Verification token from CAPTCHA challenge\n      * `channel` - Delivery channel for phone OTPs (defaults to \"sms\")\n      * `should_create_user` - Whether to create a new user if one doesn't exist (defaults to true)","ref":"Supabase.Auth.html#sign_in_with_otp/2-parameters"},{"type":"function","title":"Returns - Supabase.Auth.sign_in_with_otp/2","doc":"- `:ok` - Successfully sent OTP via email\n  - `{:ok, message_id}` - Successfully sent OTP via SMS, returns message ID\n  - `{:error, error}` - Failed to send OTP","ref":"Supabase.Auth.html#sign_in_with_otp/2-returns"},{"type":"function","title":"Examples - Supabase.Auth.sign_in_with_otp/2","doc":"iex> credentials = %{email: \"user@example.com\"}\n    iex> Supabase.Auth.sign_in_with_otp(client, credentials)\n    :ok\n    \n    iex> credentials = %{phone: \"+15555550123\", options: %{channel: \"sms\"}}\n    iex> Supabase.Auth.sign_in_with_otp(client, credentials)\n    {:ok, \"message-id-123\"}","ref":"Supabase.Auth.html#sign_in_with_otp/2-examples"},{"type":"function","title":"Supabase.Auth.sign_in_with_password/2","doc":"Authenticates a user with email/phone and password.\n\nThis is the most common authentication method used for traditional credential-based\nauthentication. Upon successful authentication, a session is created containing\naccess and refresh tokens.","ref":"Supabase.Auth.html#sign_in_with_password/2"},{"type":"function","title":"Parameters - Supabase.Auth.sign_in_with_password/2","doc":"* `client` - The Supabase client to use for the request\n* `credentials` - Map with authentication details:\n  * `email` - User's email address (required if phone not provided)\n  * `phone` - User's phone number (required if email not provided)\n  * `password` - User's password (required)\n  * `options` - Optional parameters:\n    * `captcha_token` - Verification token from CAPTCHA challenge\n    * `data` - Additional data to include with the sign in request","ref":"Supabase.Auth.html#sign_in_with_password/2-parameters"},{"type":"function","title":"Returns - Supabase.Auth.sign_in_with_password/2","doc":"* `{:ok, session}` - Successfully authenticated, returns session with tokens\n* `{:error, error}` - Authentication failed","ref":"Supabase.Auth.html#sign_in_with_password/2-returns"},{"type":"function","title":"Examples - Supabase.Auth.sign_in_with_password/2","doc":"# Sign in with email\n    iex> credentials = %{email: \"user@example.com\", password: \"secure-password\"}\n    iex> {:ok, session} = Supabase.Auth.sign_in_with_password(client, credentials)\n    iex> session.access_token\n    \"eyJhbG...\"\n    \n    # Sign in with phone\n    iex> credentials = %{phone: \"+15555550123\", password: \"secure-password\"}\n    iex> {:ok, session} = Supabase.Auth.sign_in_with_password(client, credentials)\n    \n    # Sign in with additional options\n    iex> credentials = %{\n    ...>   email: \"user@example.com\", \n    ...>   password: \"secure-password\",\n    ...>   options: %{captcha_token: \"verify-token-123\"}\n    ...> }\n    iex> {:ok, session} = Supabase.Auth.sign_in_with_password(client, credentials)","ref":"Supabase.Auth.html#sign_in_with_password/2-examples"},{"type":"function","title":"Related - Supabase.Auth.sign_in_with_password/2","doc":"* `sign_up/2` - Create a new user account with email/password\n* `reset_password_for_email/3` - Reset a forgotten password","ref":"Supabase.Auth.html#sign_in_with_password/2-related"},{"type":"function","title":"Supabase.Auth.sign_in_with_sso/2","doc":"Signs in a user with SSO (Single Sign-On).","ref":"Supabase.Auth.html#sign_in_with_sso/2"},{"type":"function","title":"Parameters - Supabase.Auth.sign_in_with_sso/2","doc":"- `client` - The `Supabase` client to use for the request.\n  - `credentials` - The credentials to use for the sign in:\n    * `provider_id` - The ID of the SSO provider (required if domain not provided)\n    * `domain` - The domain of the SSO provider (required if provider_id not provided)\n    * `options` - Optional parameters:\n      * `redirect_to` - URL to redirect the user after successful authentication\n      * `captcha_token` - Verification token from CAPTCHA challenge","ref":"Supabase.Auth.html#sign_in_with_sso/2-parameters"},{"type":"function","title":"Examples - Supabase.Auth.sign_in_with_sso/2","doc":"iex> credentials = %{domain: \"example.org\", options: %{redirect_to: \"https://example.com/callback\"}}\n    iex> Supabase.Auth.sign_in_with_sso(client, credentials)\n    {:ok, \"https://auth.supabase.com/sso/...\"}\n\n    # Or using provider_id\n    iex> credentials = %{provider_id: \"sso-provider-id\", options: %{redirect_to: \"https://example.com/callback\"}}\n    iex> Supabase.Auth.sign_in_with_sso(client, credentials)\n    {:ok, \"https://auth.supabase.com/sso/...\"}","ref":"Supabase.Auth.html#sign_in_with_sso/2-examples"},{"type":"function","title":"Supabase.Auth.sign_up/2","doc":"Signs up a user with email/phone and password.","ref":"Supabase.Auth.html#sign_up/2"},{"type":"function","title":"Parameters - Supabase.Auth.sign_up/2","doc":"- `client` - The `Supabase` client to use for the request.\n  - `credentials` - The credentials to use for the sign up:\n    * `email` - User's email address (required if phone not provided)\n    * `phone` - User's phone number (required if email not provided)\n    * `password` - User's password (required)\n    * `options` - Optional parameters:\n      * `email_redirect_to` - URL to redirect the user after email confirmation\n      * `data` - Additional data to include with the sign up\n      * `captcha_token` - Verification token from CAPTCHA challenge","ref":"Supabase.Auth.html#sign_up/2-parameters"},{"type":"function","title":"Examples - Supabase.Auth.sign_up/2","doc":"iex> credentials = %{email: \"user@example.com\", password: \"secure-password\"}\n    iex> Supabase.Auth.sign_up(client, credentials)\n    {:ok, %Supabase.Auth.User{}}","ref":"Supabase.Auth.html#sign_up/2-examples"},{"type":"function","title":"Supabase.Auth.unlink_identity/3","doc":"Unlinks an identity from the authenticated user's account.","ref":"Supabase.Auth.html#unlink_identity/3"},{"type":"function","title":"Parameters - Supabase.Auth.unlink_identity/3","doc":"- `client` - The `Supabase` client to use for the request.\n  - `session` - The session to use for the request.\n  - `identity_id` - The ID of the identity to unlink.","ref":"Supabase.Auth.html#unlink_identity/3-parameters"},{"type":"function","title":"Examples - Supabase.Auth.unlink_identity/3","doc":"iex> session = %Supabase.Auth.Session{access_token: \"example_token\"}\n    iex> identity_id = \"1234567890\"\n    iex> Supabase.Auth.unlink_identity(client, session, identity_id)\n    :ok","ref":"Supabase.Auth.html#unlink_identity/3-examples"},{"type":"function","title":"Supabase.Auth.update_user/3","doc":"Updates the current logged in user.\n\nThis function allows updating various user attributes including email, phone,\npassword, and user metadata. The user must be authenticated.","ref":"Supabase.Auth.html#update_user/3"},{"type":"function","title":"Parameters - Supabase.Auth.update_user/3","doc":"- `client` - The `Supabase` client to use for the request.\n  - `conn` - The current `Plug.Conn` or `Phoenix.LiveView.Socket` to get current user\n  - `attrs` - Attributes to update:\n    * `email` - New email address for the user\n    * `phone` - New phone number for the user\n    * `password` - New password for the user\n    * `data` - Additional user metadata to update\n    * `nonce` - Optional nonce for email change verification\n    * `email_redirect_to` - URL to redirect after email change confirmation","ref":"Supabase.Auth.html#update_user/3-parameters"},{"type":"function","title":"Returns - Supabase.Auth.update_user/3","doc":"- `{:ok, conn}` - User was successfully updated, returns updated conn with session\n  - `{:error, reason}` - Failed to update user","ref":"Supabase.Auth.html#update_user/3-returns"},{"type":"function","title":"Examples - Supabase.Auth.update_user/3","doc":"iex> params = %{email: \"another@example.com\", password: \"new-pass\"}\n    iex> Supabase.Auth.update_user(client, conn, params)\n    {:ok, conn}\n    \n    iex> params = %{data: %{name: \"John Doe\", avatar_url: \"https://example.com/avatar.png\"}}\n    iex> Supabase.Auth.update_user(client, conn, params)\n    {:ok, conn}","ref":"Supabase.Auth.html#update_user/3-examples"},{"type":"function","title":"Supabase.Auth.verify_otp/2","doc":"Verifies an OTP (One-Time Password) code.\n\nThis function completes the authentication process started with `sign_in_with_otp/2`\nby verifying the OTP code that was sent to the user's email or phone.","ref":"Supabase.Auth.html#verify_otp/2"},{"type":"function","title":"Parameters - Supabase.Auth.verify_otp/2","doc":"- `client` - The `Supabase` client to use for the request.\n  - `params` - The parameters to use for the verification. Use one of the following formats:\n    \n    For email verification:\n    * `email` - The email address that received the OTP\n    * `token` - The OTP code that was sent\n    * `type` - The verification type (`:signup`, `:invite`, `:magiclink`, `:recovery`, `:email_change`)\n    * `options` - Optional parameters:\n      * `redirect_to` - URL to redirect to after verification\n      * `captcha_token` - Verification token from CAPTCHA challenge\n    \n    For phone verification:\n    * `phone` - The phone number that received the OTP\n    * `token` - The OTP code that was sent\n    * `type` - The verification type (`:sms`, `:phone_change`)\n    * `options` - Optional parameters:\n      * `redirect_to` - URL to redirect to after verification\n      * `captcha_token` - Verification token from CAPTCHA challenge\n    \n    For token hash verification:\n    * `token_hash` - The token hash to verify\n    * `type` - The verification type (same as email verification types)\n    * `options` - Optional parameters (same as above)","ref":"Supabase.Auth.html#verify_otp/2-parameters"},{"type":"function","title":"Returns - Supabase.Auth.verify_otp/2","doc":"- `{:ok, session}` - Successfully verified OTP, returns a session with tokens\n  - `{:error, error}` - Failed to verify OTP","ref":"Supabase.Auth.html#verify_otp/2-returns"},{"type":"function","title":"Examples - Supabase.Auth.verify_otp/2","doc":"iex> params = %{email: \"user@example.com\", token: \"123456\", type: :signup}\n    iex> Supabase.Auth.verify_otp(client, params)\n    {:ok, %Supabase.Auth.Session{}}\n    \n    iex> params = %{phone: \"+15555550123\", token: \"123456\", type: :sms}\n    iex> Supabase.Auth.verify_otp(client, params)\n    {:ok, %Supabase.Auth.Session{}}","ref":"Supabase.Auth.html#verify_otp/2-examples"},{"type":"module","title":"Supabase.Auth.Admin","doc":"Admin module for Auth. This module provides functions to interact with the Auth admin API,\nlike signing out a user, inviting a user, and generating a link.\n\nYou can find more information about the Auth admin API at https://supabase.io/docs/reference/javascript/auth-admin-api","ref":"Supabase.Auth.Admin.html"},{"type":"function","title":"Supabase.Auth.Admin.create_user/2","doc":"Creates a user via the admin API.","ref":"Supabase.Auth.Admin.html#create_user/2"},{"type":"function","title":"Parameters - Supabase.Auth.Admin.create_user/2","doc":"* `client` - The `Supabase` client to use for the request.\n  * `attrs` - The attributes to use for the user:\n    * `email` - User's email address (required if phone not provided)\n    * `phone` - User's phone number (required if email not provided)\n    * `password` - User's password\n    * `email_confirm` - Whether to mark the email as confirmed\n    * `phone_confirm` - Whether to mark the phone as confirmed\n    * `app_metadata` - Application-specific metadata to store with the user\n    * `ban_duration` - Duration for which the user should be banned\n    * `role` - User's role\n    * `nonce` - Custom nonce for the user","ref":"Supabase.Auth.Admin.html#create_user/2-parameters"},{"type":"function","title":"Returns - Supabase.Auth.Admin.create_user/2","doc":"* `{:ok, user}` - Successfully created user\n  * `{:error, error}` - Failed to create user","ref":"Supabase.Auth.Admin.html#create_user/2-returns"},{"type":"function","title":"Examples - Supabase.Auth.Admin.create_user/2","doc":"iex> attrs = %{email: \"admin-created@example.com\", password: \"secure-password\", email_confirm: true}\n    iex> Supabase.Auth.Admin.create_user(client, attrs)\n    {:ok, %Supabase.Auth.User{}}","ref":"Supabase.Auth.Admin.html#create_user/2-examples"},{"type":"function","title":"Supabase.Auth.Admin.delete_factor/3","doc":"Deletes a multi-factor authentication factor for a user.","ref":"Supabase.Auth.Admin.html#delete_factor/3"},{"type":"function","title":"Parameters - Supabase.Auth.Admin.delete_factor/3","doc":"* `client` - The `Supabase` client to use for the request.\n  * `user_id` - The ID of the user.\n  * `factor_id` - The ID of the factor to delete.","ref":"Supabase.Auth.Admin.html#delete_factor/3-parameters"},{"type":"function","title":"Returns - Supabase.Auth.Admin.delete_factor/3","doc":"* `:ok` - Successfully deleted the factor\n  * `{:error, error}` - Failed to delete the factor","ref":"Supabase.Auth.Admin.html#delete_factor/3-returns"},{"type":"function","title":"Examples - Supabase.Auth.Admin.delete_factor/3","doc":"iex> Supabase.Auth.Admin.delete_factor(client, \"d5bd2ef9-8df8-4e96-b592-35d120a8634c\", \"totp-factor-id\")\n    :ok","ref":"Supabase.Auth.Admin.html#delete_factor/3-examples"},{"type":"function","title":"Supabase.Auth.Admin.delete_identity/3","doc":"Removes a specific authentication identity from a user.","ref":"Supabase.Auth.Admin.html#delete_identity/3"},{"type":"function","title":"Parameters - Supabase.Auth.Admin.delete_identity/3","doc":"* `client` - The `Supabase` client to use for the request.\n  * `user_id` - The ID of the user.\n  * `identity_id` - The ID of the identity to delete.","ref":"Supabase.Auth.Admin.html#delete_identity/3-parameters"},{"type":"function","title":"Returns - Supabase.Auth.Admin.delete_identity/3","doc":"* `:ok` - Successfully deleted the identity\n  * `{:error, error}` - Failed to delete the identity","ref":"Supabase.Auth.Admin.html#delete_identity/3-returns"},{"type":"function","title":"Examples - Supabase.Auth.Admin.delete_identity/3","doc":"iex> Supabase.Auth.Admin.delete_identity(client, \"d5bd2ef9-8df8-4e96-b592-35d120a8634c\", \"identity-id\")\n    :ok","ref":"Supabase.Auth.Admin.html#delete_identity/3-examples"},{"type":"function","title":"Supabase.Auth.Admin.delete_user/3","doc":"Deletes a user via the admin API.","ref":"Supabase.Auth.Admin.html#delete_user/3"},{"type":"function","title":"Parameters - Supabase.Auth.Admin.delete_user/3","doc":"* `client` - The `Supabase` client to use for the request.\n  * `user_id` - The ID of the user to delete.\n  * `opts` - Controls deletion behavior.\n    * `should_soft_delete` - When true, the user will be soft-deleted (default: false)","ref":"Supabase.Auth.Admin.html#delete_user/3-parameters"},{"type":"function","title":"Returns - Supabase.Auth.Admin.delete_user/3","doc":"* `{:ok, user}` - Successfully deleted user (returns user data)\n  * `{:error, error}` - Failed to delete user","ref":"Supabase.Auth.Admin.html#delete_user/3-returns"},{"type":"function","title":"Examples - Supabase.Auth.Admin.delete_user/3","doc":"iex> Supabase.Auth.Admin.delete_user(client, \"user_id\")\n    {:ok, %Supabase.Auth.User{}}\n    \n    # Soft delete a user\n    iex> Supabase.Auth.Admin.delete_user(client, \"user_id\", should_soft_delete: true)\n    {:ok, %Supabase.Auth.User{}}","ref":"Supabase.Auth.Admin.html#delete_user/3-examples"},{"type":"function","title":"Supabase.Auth.Admin.generate_link/2","doc":"Generates an action link for various authentication purposes.","ref":"Supabase.Auth.Admin.html#generate_link/2"},{"type":"function","title":"Parameters - Supabase.Auth.Admin.generate_link/2","doc":"* `client` - The `Supabase` client to use for the request.\n  * `attrs` - The attributes to use for the link:\n    * `email` - The email for which to generate the link (required)\n    * `type` - The type of link to generate (required). One of:\n      * `signup` - Sign up link (requires password)\n      * `invite` - Invitation link\n      * `magicLink` - Magic link for passwordless auth\n      * `recovery` - Password recovery link\n      * `email_change_current` - Email change confirmation for current email\n      * `email_change_new` - Email change confirmation for new email\n    * `password` - Required for signup links\n    * `redirect_to` - URL to redirect after action is completed\n    * `data` - Additional data to include","ref":"Supabase.Auth.Admin.html#generate_link/2-parameters"},{"type":"function","title":"Returns - Supabase.Auth.Admin.generate_link/2","doc":"* `{:ok, properties}` - Successfully generated link with properties:\n  * `action_link` - The link to send to the user\n  * `email_otp` - Email OTP if applicable\n  * `hashed_token` - Hashed token\n  * `redirect_to` - The redirect URL\n  * `verification_type` - Type of verification","ref":"Supabase.Auth.Admin.html#generate_link/2-returns"},{"type":"function","title":"Examples - Supabase.Auth.Admin.generate_link/2","doc":"iex> attrs = %{email: \"user@example.com\", type: \"recovery\", redirect_to: \"https://example.com/reset-password\"}\n    iex> Supabase.Auth.Admin.generate_link(client, attrs)\n    {:ok, %{action_link: \"https://auth.example.com/verify?...\", ...}}","ref":"Supabase.Auth.Admin.html#generate_link/2-examples"},{"type":"function","title":"Supabase.Auth.Admin.get_user_by_id/2","doc":"Gets a user by ID via the admin API.","ref":"Supabase.Auth.Admin.html#get_user_by_id/2"},{"type":"function","title":"Parameters - Supabase.Auth.Admin.get_user_by_id/2","doc":"* `client` - The `Supabase` client to use for the request.\n  * `user_id` - The ID of the user to get.","ref":"Supabase.Auth.Admin.html#get_user_by_id/2-parameters"},{"type":"function","title":"Returns - Supabase.Auth.Admin.get_user_by_id/2","doc":"* `{:ok, user}` - Successfully retrieved user\n  * `{:error, error}` - Failed to retrieve user","ref":"Supabase.Auth.Admin.html#get_user_by_id/2-returns"},{"type":"function","title":"Examples - Supabase.Auth.Admin.get_user_by_id/2","doc":"iex> Supabase.Auth.Admin.get_user_by_id(client, \"d5bd2ef9-8df8-4e96-b592-35d120a8634c\")\n    {:ok, %Supabase.Auth.User{}}","ref":"Supabase.Auth.Admin.html#get_user_by_id/2-examples"},{"type":"function","title":"Supabase.Auth.Admin.invite_user_by_email/3","doc":"Invites a user to join the application through email.","ref":"Supabase.Auth.Admin.html#invite_user_by_email/3"},{"type":"function","title":"Parameters - Supabase.Auth.Admin.invite_user_by_email/3","doc":"* `client` - The `Supabase` client to use for the request.\n  * `email` - The email of the user to invite.\n  * `options` - The options to use for the invite:\n    * `data` - Additional data to include with the invitation\n    * `redirect_to` - URL to redirect the user after accepting the invitation","ref":"Supabase.Auth.Admin.html#invite_user_by_email/3-parameters"},{"type":"function","title":"Examples - Supabase.Auth.Admin.invite_user_by_email/3","doc":"iex> Supabase.Auth.Admin.invite_user_by_email(client, \"john@example.com\", %{redirect_to: \"https://example.com/welcome\"})","ref":"Supabase.Auth.Admin.html#invite_user_by_email/3-examples"},{"type":"function","title":"Supabase.Auth.Admin.list_identities/2","doc":"Lists all connected authentication identities for a specific user.","ref":"Supabase.Auth.Admin.html#list_identities/2"},{"type":"function","title":"Parameters - Supabase.Auth.Admin.list_identities/2","doc":"* `client` - The `Supabase` client to use for the request.\n  * `user_id` - The ID of the user.","ref":"Supabase.Auth.Admin.html#list_identities/2-parameters"},{"type":"function","title":"Returns - Supabase.Auth.Admin.list_identities/2","doc":"* `{:ok, identities}` - Successfully retrieved the list of identities\n  * `{:error, error}` - Failed to retrieve the identities","ref":"Supabase.Auth.Admin.html#list_identities/2-returns"},{"type":"function","title":"Examples - Supabase.Auth.Admin.list_identities/2","doc":"iex> Supabase.Auth.Admin.list_identities(client, \"d5bd2ef9-8df8-4e96-b592-35d120a8634c\")\n    {:ok, [%Supabase.Auth.User.Identity{provider: :google, ...}, ...]}","ref":"Supabase.Auth.Admin.html#list_identities/2-examples"},{"type":"function","title":"Supabase.Auth.Admin.list_users/2","doc":"Lists users via the admin API with pagination support.","ref":"Supabase.Auth.Admin.html#list_users/2"},{"type":"function","title":"Parameters - Supabase.Auth.Admin.list_users/2","doc":"* `client` - The `Supabase` client to use for the request.\n  * `params` - The parameters to use for the list:\n    * `page` - Page number for pagination\n    * `per_page` - Number of users per page","ref":"Supabase.Auth.Admin.html#list_users/2-parameters"},{"type":"function","title":"Returns - Supabase.Auth.Admin.list_users/2","doc":"* `{:ok, users, pagination}` - Successfully retrieved users with pagination info\n    * `users` - List of user objects\n    * `pagination` - Pagination metadata including next_page, last_page, and total count\n  * `{:error, error}` - Failed to retrieve users","ref":"Supabase.Auth.Admin.html#list_users/2-returns"},{"type":"function","title":"Examples - Supabase.Auth.Admin.list_users/2","doc":"iex> Supabase.Auth.Admin.list_users(client, %{page: 1, per_page: 10})\n    {:ok, [%Supabase.Auth.User{}, ...], %{next_page: 2, last_page: 5, total: 42}}","ref":"Supabase.Auth.Admin.html#list_users/2-examples"},{"type":"function","title":"Supabase.Auth.Admin.sign_out/3","doc":"Signs out a user via the admin API.","ref":"Supabase.Auth.Admin.html#sign_out/3"},{"type":"function","title":"Parameters - Supabase.Auth.Admin.sign_out/3","doc":"* `client` - The `Supabase` client to use for the request.\n  * `session` - The session to sign out, often retrieved from a sign in function.\n  * `scope` - The scope to sign out the user from (atom):\n    * `:global` - Sign out user from all devices and browser sessions\n    * `:local` - Sign out user from current browser only\n    * `:others` - Sign out user from all other devices except current browser","ref":"Supabase.Auth.Admin.html#sign_out/3-parameters"},{"type":"function","title":"Returns - Supabase.Auth.Admin.sign_out/3","doc":"* `:ok` - Successfully signed out the user\n  * `{:error, error}` - Failed to sign out the user","ref":"Supabase.Auth.Admin.html#sign_out/3-returns"},{"type":"function","title":"Examples - Supabase.Auth.Admin.sign_out/3","doc":"iex> session = %Session{access_token: \"eyJhbGciO...\"}\n    iex> Supabase.Auth.Admin.sign_out(client, session, :global)\n    :ok","ref":"Supabase.Auth.Admin.html#sign_out/3-examples"},{"type":"function","title":"Supabase.Auth.Admin.update_user_by_id/3","doc":"Updates a user via the admin API.","ref":"Supabase.Auth.Admin.html#update_user_by_id/3"},{"type":"function","title":"Parameters - Supabase.Auth.Admin.update_user_by_id/3","doc":"* `client` - The `Supabase` client to use for the request.\n  * `user_id` - The ID of the user to update.\n  * `attrs` - The attributes to update for the user:\n    * `email` - User's email address\n    * `phone` - User's phone number\n    * `password` - User's password\n    * `email_confirm` - Whether to mark the email as confirmed\n    * `phone_confirm` - Whether to mark the phone as confirmed\n    * `app_metadata` - Application-specific metadata to store with the user\n    * `ban_duration` - Duration for which the user should be banned\n    * `role` - User's role\n    * `nonce` - Custom nonce for the user","ref":"Supabase.Auth.Admin.html#update_user_by_id/3-parameters"},{"type":"function","title":"Returns - Supabase.Auth.Admin.update_user_by_id/3","doc":"* `{:ok, user}` - Successfully updated user\n  * `{:error, error}` - Failed to update user","ref":"Supabase.Auth.Admin.html#update_user_by_id/3-returns"},{"type":"function","title":"Examples - Supabase.Auth.Admin.update_user_by_id/3","doc":"iex> attrs = %{role: \"admin\", app_metadata: %{plan: \"premium\"}}\n    iex> Supabase.Auth.Admin.update_user_by_id(client, \"d5bd2ef9-8df8-4e96-b592-35d120a8634c\", attrs)\n    {:ok, %Supabase.Auth.User{}}","ref":"Supabase.Auth.Admin.html#update_user_by_id/3-examples"},{"type":"module","title":"Supabase.Auth.Admin.LinkFixture","doc":"This module is used to generate a link fixture for testing.","ref":"Supabase.Auth.Admin.LinkFixture.html"},{"type":"function","title":"Supabase.Auth.Admin.LinkFixture.link_fixture/1","doc":"","ref":"Supabase.Auth.Admin.LinkFixture.html#link_fixture/1"},{"type":"function","title":"Supabase.Auth.Admin.LinkFixture.link_fixture_json/1","doc":"","ref":"Supabase.Auth.Admin.LinkFixture.html#link_fixture_json/1"},{"type":"module","title":"Supabase.Auth.Admin.UserFixture","doc":"This module is used to generate a user fixture for testing admin APIs.","ref":"Supabase.Auth.Admin.UserFixture.html"},{"type":"function","title":"Supabase.Auth.Admin.UserFixture.user_create_fixture/1","doc":"","ref":"Supabase.Auth.Admin.UserFixture.html#user_create_fixture/1"},{"type":"behaviour","title":"Supabase.Auth.AdminBehaviour","doc":"Behaviour specification for the Supabase.Auth.Admin module.\n\nThis module defines the contract that any Auth Admin implementation must fulfill,\nproviding function specifications and return types for all admin operations.","ref":"Supabase.Auth.AdminBehaviour.html"},{"type":"callback","title":"Supabase.Auth.AdminBehaviour.create_user/2","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#c:create_user/2"},{"type":"callback","title":"Supabase.Auth.AdminBehaviour.delete_factor/3","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#c:delete_factor/3"},{"type":"callback","title":"Supabase.Auth.AdminBehaviour.delete_identity/3","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#c:delete_identity/3"},{"type":"callback","title":"Supabase.Auth.AdminBehaviour.delete_user/3","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#c:delete_user/3"},{"type":"callback","title":"Supabase.Auth.AdminBehaviour.generate_link/2","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#c:generate_link/2"},{"type":"callback","title":"Supabase.Auth.AdminBehaviour.get_user_by_id/2","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#c:get_user_by_id/2"},{"type":"type","title":"Supabase.Auth.AdminBehaviour.invite_options/0","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#t:invite_options/0"},{"type":"callback","title":"Supabase.Auth.AdminBehaviour.invite_user_by_email/3","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#c:invite_user_by_email/3"},{"type":"callback","title":"Supabase.Auth.AdminBehaviour.list_identities/2","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#c:list_identities/2"},{"type":"callback","title":"Supabase.Auth.AdminBehaviour.list_users/2","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#c:list_users/2"},{"type":"type","title":"Supabase.Auth.AdminBehaviour.pagination/0","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#t:pagination/0"},{"type":"type","title":"Supabase.Auth.AdminBehaviour.scope/0","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#t:scope/0"},{"type":"callback","title":"Supabase.Auth.AdminBehaviour.sign_out/3","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#c:sign_out/3"},{"type":"callback","title":"Supabase.Auth.AdminBehaviour.update_user_by_id/3","doc":"","ref":"Supabase.Auth.AdminBehaviour.html#c:update_user_by_id/3"},{"type":"module","title":"Supabase.Auth.AutoRefresh","doc":"A GenServer to automatically refresh auth tokens before they expire.","ref":"Supabase.Auth.AutoRefresh.html"},{"type":"module","title":"Usage - Supabase.Auth.AutoRefresh","doc":"Add this GenServer to your application's supervision tree:\n\n```elixir\n# In your application.ex\ndef start(_type, _args) do\n  children = [\n    # ... other children\n    {Supabase.Registry, keys: :unique, name: Supabase.Registry},\n    {DynamicSupervisor, strategy: :one_for_one, name: Supabase.AutoRefreshSupervisor}\n    # ... rest of your supervision tree\n  ]\n\n  opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n```\n\nThen start the auto-refresh process when you get a new session:\n\n```elixir\n{:ok, pid} = DynamicSupervisor.start_child(\n  Supabase.AutoRefreshSupervisor,\n  {Supabase.Auth.AutoRefresh, {client, session}}\n)\n```\n\nTo stop refreshing when the user logs out:\n\n```elixir\nSupabase.Auth.AutoRefresh.stop(client)\n```","ref":"Supabase.Auth.AutoRefresh.html#module-usage"},{"type":"function","title":"Supabase.Auth.AutoRefresh.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Supabase.Auth.AutoRefresh.html#child_spec/1"},{"type":"function","title":"Supabase.Auth.AutoRefresh.init/1","doc":"Callback implementation for  GenServer.init/1 .","ref":"Supabase.Auth.AutoRefresh.html#init/1"},{"type":"function","title":"Supabase.Auth.AutoRefresh.needs_refresh?/1","doc":"","ref":"Supabase.Auth.AutoRefresh.html#needs_refresh?/1"},{"type":"function","title":"Supabase.Auth.AutoRefresh.start_link/1","doc":"","ref":"Supabase.Auth.AutoRefresh.html#start_link/1"},{"type":"function","title":"Supabase.Auth.AutoRefresh.stop/1","doc":"","ref":"Supabase.Auth.AutoRefresh.html#stop/1"},{"type":"behaviour","title":"Supabase.Auth.Behaviour","doc":"Behaviour specification for the Supabase.Auth module.\n\nThis module defines the contract that any Auth implementation must fulfill,\nproviding function specifications and return types for all authentication operations.","ref":"Supabase.Auth.Behaviour.html"},{"type":"type","title":"Supabase.Auth.Behaviour.conn/0","doc":"","ref":"Supabase.Auth.Behaviour.html#t:conn/0"},{"type":"callback","title":"Supabase.Auth.Behaviour.exchange_code_for_session/4","doc":"","ref":"Supabase.Auth.Behaviour.html#c:exchange_code_for_session/4"},{"type":"callback","title":"Supabase.Auth.Behaviour.get_server_health/1","doc":"","ref":"Supabase.Auth.Behaviour.html#c:get_server_health/1"},{"type":"callback","title":"Supabase.Auth.Behaviour.get_server_settings/1","doc":"","ref":"Supabase.Auth.Behaviour.html#c:get_server_settings/1"},{"type":"callback","title":"Supabase.Auth.Behaviour.get_user/2","doc":"","ref":"Supabase.Auth.Behaviour.html#c:get_user/2"},{"type":"callback","title":"Supabase.Auth.Behaviour.get_user_identities/2","doc":"","ref":"Supabase.Auth.Behaviour.html#c:get_user_identities/2"},{"type":"callback","title":"Supabase.Auth.Behaviour.link_identity/3","doc":"","ref":"Supabase.Auth.Behaviour.html#c:link_identity/3"},{"type":"callback","title":"Supabase.Auth.Behaviour.reauthenticate/2","doc":"","ref":"Supabase.Auth.Behaviour.html#c:reauthenticate/2"},{"type":"callback","title":"Supabase.Auth.Behaviour.refresh_session/2","doc":"","ref":"Supabase.Auth.Behaviour.html#c:refresh_session/2"},{"type":"callback","title":"Supabase.Auth.Behaviour.resend/3","doc":"","ref":"Supabase.Auth.Behaviour.html#c:resend/3"},{"type":"callback","title":"Supabase.Auth.Behaviour.reset_password_for_email/3","doc":"","ref":"Supabase.Auth.Behaviour.html#c:reset_password_for_email/3"},{"type":"callback","title":"Supabase.Auth.Behaviour.sign_in_anonymously/2","doc":"","ref":"Supabase.Auth.Behaviour.html#c:sign_in_anonymously/2"},{"type":"type","title":"Supabase.Auth.Behaviour.sign_in_response/0","doc":"","ref":"Supabase.Auth.Behaviour.html#t:sign_in_response/0"},{"type":"callback","title":"Supabase.Auth.Behaviour.sign_in_with_id_token/2","doc":"","ref":"Supabase.Auth.Behaviour.html#c:sign_in_with_id_token/2"},{"type":"callback","title":"Supabase.Auth.Behaviour.sign_in_with_oauth/2","doc":"","ref":"Supabase.Auth.Behaviour.html#c:sign_in_with_oauth/2"},{"type":"callback","title":"Supabase.Auth.Behaviour.sign_in_with_otp/2","doc":"","ref":"Supabase.Auth.Behaviour.html#c:sign_in_with_otp/2"},{"type":"callback","title":"Supabase.Auth.Behaviour.sign_in_with_password/2","doc":"","ref":"Supabase.Auth.Behaviour.html#c:sign_in_with_password/2"},{"type":"callback","title":"Supabase.Auth.Behaviour.sign_in_with_sso/2","doc":"","ref":"Supabase.Auth.Behaviour.html#c:sign_in_with_sso/2"},{"type":"callback","title":"Supabase.Auth.Behaviour.sign_up/2","doc":"","ref":"Supabase.Auth.Behaviour.html#c:sign_up/2"},{"type":"callback","title":"Supabase.Auth.Behaviour.unlink_identity/3","doc":"","ref":"Supabase.Auth.Behaviour.html#c:unlink_identity/3"},{"type":"callback","title":"Supabase.Auth.Behaviour.update_user/3","doc":"","ref":"Supabase.Auth.Behaviour.html#c:update_user/3"},{"type":"callback","title":"Supabase.Auth.Behaviour.verify_otp/2","doc":"","ref":"Supabase.Auth.Behaviour.html#c:verify_otp/2"},{"type":"module","title":"Supabase.Auth.LiveView","doc":"Provides LiveView integrations for the Supabase Auth authentication in Elixir applications.\n\nThis module enables the seamless integration of authentication flows within Phoenix LiveView applications by leveraging the Supabase Auth SDK. It supports operations such as mounting current users, handling authenticated and unauthenticated states, and logging out users.","ref":"Supabase.Auth.LiveView.html"},{"type":"module","title":"Configuration - Supabase.Auth.LiveView","doc":"The module requires some application environment variables to be set:\n- `authentication_client`: The Supabase client used for authentication.\n- `endpoint`: Your web app endpoint, used internally for broadcasting user disconnection events.\n- `signed_in_path`: The route to where socket should be redirected to after authentication\n- `not_authenticated_path`: The route to where socket should be redirect to if user isn't authenticated","ref":"Supabase.Auth.LiveView.html#module-configuration"},{"type":"module","title":"Usage - Supabase.Auth.LiveView","doc":"Typically, you need to define a module to be your LiveView Authentication entrypoint and use this module to inject the necessary functions that you will use on your `MyAppWeb.Router`, to handle user authentication states through a series of `on_mount` callbacks, which ensure that user authentication logic is processed during the LiveView lifecycle.\n\nCheck `on_mount/4` for more detailed usage instructions on LiveViews","ref":"Supabase.Auth.LiveView.html#module-usage"},{"type":"module","title":"Example - Supabase.Auth.LiveView","doc":"defmodule MyAppWeb.Auth do\n      use Supabase.Auth.LiveView,\n        endpoint: MyAppWeb.Endpoint,\n        client: MyApp.Supabase.Client,\n        signed_in_path: \"/app\",\n        not_authenticated_path: \"/login\"\n    end","ref":"Supabase.Auth.LiveView.html#module-example"},{"type":"module","title":"Supabase.Auth.PKCE","doc":"This module is used to generate PKCE (Proof Key for Code Exchange) values.","ref":"Supabase.Auth.PKCE.html"},{"type":"function","title":"Supabase.Auth.PKCE.generate_challenge/1","doc":"Generate a challenge from a verifier. The challenge is used to\nverify the verifier when exchanging the code.","ref":"Supabase.Auth.PKCE.html#generate_challenge/1"},{"type":"function","title":"Examples - Supabase.Auth.PKCE.generate_challenge/1","doc":"iex> verifier = Supabase.Auth.PKCE.generate_verifier()\n    iex> Supabase.Auth.PKCE.generate_challenge(verifier)","ref":"Supabase.Auth.PKCE.html#generate_challenge/1-examples"},{"type":"function","title":"Supabase.Auth.PKCE.generate_verifier/0","doc":"Generate a random string of a fized 56 length to be used as the\ncode verifier.","ref":"Supabase.Auth.PKCE.html#generate_verifier/0"},{"type":"function","title":"Examples - Supabase.Auth.PKCE.generate_verifier/0","doc":"iex> Supabase.Auth.PKCE.generate_verifier()","ref":"Supabase.Auth.PKCE.html#generate_verifier/0-examples"},{"type":"module","title":"Supabase.Auth.Plug","doc":"Provides Plug-based authentication support for the Supabase Auth authentication in Elixir applications.\n\nThis module offers a series of functions to manage user authentication through HTTP requests in Phoenix applications. It facilitates operations like logging in with a password, logging out users, fetching the current user from a session, and handling route protections based on authentication state.","ref":"Supabase.Auth.Plug.html"},{"type":"module","title":"Configuration - Supabase.Auth.Plug","doc":"The module requires some application environment variables to be set:\n- `authentication_client`: The Supabase client used for authentication.\n- `endpoint`: Your web app endpoint, used internally for broadcasting user disconnection events.\n- `signed_in_path`: The route to where socket should be redirected to after authentication\n- `not_authenticated_path`: The route to where socket should be redirect to if user isn't authenticated","ref":"Supabase.Auth.Plug.html#module-configuration"},{"type":"module","title":"Usage - Supabase.Auth.Plug","doc":"Typically, you need to define a module to be your Plug Authentication entrypoint and use this module to inject the necessary functions that you will use on your `MyAppWeb.Router`.","ref":"Supabase.Auth.Plug.html#module-usage"},{"type":"module","title":"Supabase.Auth.Request.JSONDecoder","doc":"A body decoder that transforms empty response to a valid map.","ref":"Supabase.Auth.Request.JSONDecoder.html"},{"type":"module","title":"Supabase.Auth.Schemas.ResendParams","doc":"Parameters for resending confirmation or verification emails/SMS.\n\nThis schema is used by `Supabase.Auth.resend/3` to define the parameters\nfor resending verification codes or confirmation emails to users.","ref":"Supabase.Auth.Schemas.ResendParams.html"},{"type":"module","title":"Fields - Supabase.Auth.Schemas.ResendParams","doc":"* `type` - The type of verification to resend (`:sms`, `:signup`, `:phone_change`, `:email_change`)\n* `options` - Additional options:\n  * `email_redirect_to` - URL to redirect after email confirmation\n  * `captcha_token` - Token from CAPTCHA verification if enabled","ref":"Supabase.Auth.Schemas.ResendParams.html#module-fields"},{"type":"type","title":"Supabase.Auth.Schemas.ResendParams.options/0","doc":"","ref":"Supabase.Auth.Schemas.ResendParams.html#t:options/0"},{"type":"type","title":"Supabase.Auth.Schemas.ResendParams.otp_type/0","doc":"","ref":"Supabase.Auth.Schemas.ResendParams.html#t:otp_type/0"},{"type":"function","title":"Supabase.Auth.Schemas.ResendParams.parse/2","doc":"","ref":"Supabase.Auth.Schemas.ResendParams.html#parse/2"},{"type":"type","title":"Supabase.Auth.Schemas.ResendParams.t/0","doc":"","ref":"Supabase.Auth.Schemas.ResendParams.html#t:t/0"},{"type":"module","title":"Supabase.Auth.Schemas.ServerHealth","doc":"Represents the health information of the Auth authentication server.\n\nThis struct is returned by `Supabase.Auth.get_server_health/1` and contains\ninformation about the server's status, version, and other diagnostic data.","ref":"Supabase.Auth.Schemas.ServerHealth.html"},{"type":"module","title":"Fields - Supabase.Auth.Schemas.ServerHealth","doc":"* `version` - The version of the Auth server\n* `name` - The name of the service (typically \"Auth\")\n* `description` - A brief description of the service","ref":"Supabase.Auth.Schemas.ServerHealth.html#module-fields"},{"type":"function","title":"Supabase.Auth.Schemas.ServerHealth.parse/2","doc":"","ref":"Supabase.Auth.Schemas.ServerHealth.html#parse/2"},{"type":"type","title":"Supabase.Auth.Schemas.ServerHealth.t/0","doc":"","ref":"Supabase.Auth.Schemas.ServerHealth.html#t:t/0"},{"type":"module","title":"Supabase.Auth.Schemas.ServerSettings","doc":"Represents the configuration settings of the Auth authentication server.\n\nThis struct is returned by `Supabase.Auth.get_server_settings/1` and contains\ninformation about the server's configuration, including available authentication\nmethods and provider settings.","ref":"Supabase.Auth.Schemas.ServerSettings.html"},{"type":"module","title":"Fields - Supabase.Auth.Schemas.ServerSettings","doc":"* `disable_signup` - Whether new user signups are allowed\n* `mailer_autoconfirm` - Whether email signups are automatically confirmed\n* `phone_autoconfirm` - Whether phone signups are automatically confirmed\n* `sms_provider` - The provider used for SMS messaging\n* `saml_enabled` - Whether SAML authentication is enabled\n* `external` - Settings for external authentication providers\n  * See `external_t()` type for all provider fields","ref":"Supabase.Auth.Schemas.ServerSettings.html#module-fields"},{"type":"module","title":"External Providers - Supabase.Auth.Schemas.ServerSettings","doc":"The `external` field contains boolean flags indicating which authentication\nproviders are enabled, such as:\n\n* `anonymous_users` - Anonymous authentication\n* `email` - Email/password authentication\n* `phone` - Phone authentication\n* Third-party providers (`google`, `github`, etc.)","ref":"Supabase.Auth.Schemas.ServerSettings.html#module-external-providers"},{"type":"type","title":"Supabase.Auth.Schemas.ServerSettings.external_t/0","doc":"","ref":"Supabase.Auth.Schemas.ServerSettings.html#t:external_t/0"},{"type":"function","title":"Supabase.Auth.Schemas.ServerSettings.parse/2","doc":"","ref":"Supabase.Auth.Schemas.ServerSettings.html#parse/2"},{"type":"type","title":"Supabase.Auth.Schemas.ServerSettings.t/0","doc":"","ref":"Supabase.Auth.Schemas.ServerSettings.html#t:t/0"},{"type":"module","title":"Supabase.Auth.Schemas.SignInAnonymously","doc":"Parameters for anonymous sign-in.\n\nThis schema is used by `Supabase.Auth.sign_in_anonymously/2` to define the \nparameters for creating a new anonymous user. Anonymous users can later be \nconverted to permanent users by linking identities or adding credentials.","ref":"Supabase.Auth.Schemas.SignInAnonymously.html"},{"type":"module","title":"Fields - Supabase.Auth.Schemas.SignInAnonymously","doc":"* `data` - Additional user metadata to include with the sign-in request\n* `captcha_token` - Verification token from CAPTCHA challenge if enabled","ref":"Supabase.Auth.Schemas.SignInAnonymously.html#module-fields"},{"type":"function","title":"Supabase.Auth.Schemas.SignInAnonymously.parse/2","doc":"","ref":"Supabase.Auth.Schemas.SignInAnonymously.html#parse/2"},{"type":"type","title":"Supabase.Auth.Schemas.SignInAnonymously.t/0","doc":"","ref":"Supabase.Auth.Schemas.SignInAnonymously.html#t:t/0"},{"type":"function","title":"Supabase.Auth.Schemas.SignInAnonymously.to_sign_in_params/1","doc":"","ref":"Supabase.Auth.Schemas.SignInAnonymously.html#to_sign_in_params/1"},{"type":"module","title":"Supabase.Auth.Schemas.UserParams","doc":"Parameters for updating user profiles.\n\nThis schema is used by `Supabase.Auth.update_user/3` to define the \nparameters for updating an authenticated user's profile information.","ref":"Supabase.Auth.Schemas.UserParams.html"},{"type":"module","title":"Fields - Supabase.Auth.Schemas.UserParams","doc":"* `email` - New email address for the user\n* `phone` - New phone number for the user\n* `password` - New password for the user\n* `data` - Additional user metadata to update\n* `nonce` - Optional nonce for email change verification\n* `email_redirect_to` - URL to redirect after email change confirmation","ref":"Supabase.Auth.Schemas.UserParams.html#module-fields"},{"type":"function","title":"Supabase.Auth.Schemas.UserParams.parse/1","doc":"","ref":"Supabase.Auth.Schemas.UserParams.html#parse/1"},{"type":"function","title":"Supabase.Auth.Schemas.UserParams.parse_update/1","doc":"","ref":"Supabase.Auth.Schemas.UserParams.html#parse_update/1"},{"type":"type","title":"Supabase.Auth.Schemas.UserParams.t/0","doc":"","ref":"Supabase.Auth.Schemas.UserParams.html#t:t/0"},{"type":"module","title":"Supabase.Auth.ServerHealthFixture","doc":"Server health fixture for Auth. This module provides functions to generate server health fixtures.","ref":"Supabase.Auth.ServerHealthFixture.html"},{"type":"function","title":"Supabase.Auth.ServerHealthFixture.server_health_fixture/1","doc":"","ref":"Supabase.Auth.ServerHealthFixture.html#server_health_fixture/1"},{"type":"function","title":"Supabase.Auth.ServerHealthFixture.server_health_fixture_json/1","doc":"","ref":"Supabase.Auth.ServerHealthFixture.html#server_health_fixture_json/1"},{"type":"module","title":"Supabase.Auth.ServerSettingsFixture","doc":"Server settings fixture for Auth. This module provides functions to generate server settings fixtures.","ref":"Supabase.Auth.ServerSettingsFixture.html"},{"type":"function","title":"Supabase.Auth.ServerSettingsFixture.server_settings_fixture/1","doc":"","ref":"Supabase.Auth.ServerSettingsFixture.html#server_settings_fixture/1"},{"type":"function","title":"Supabase.Auth.ServerSettingsFixture.server_settings_fixture_json/1","doc":"","ref":"Supabase.Auth.ServerSettingsFixture.html#server_settings_fixture_json/1"},{"type":"module","title":"Supabase.Auth.Session","doc":"Represents an authenticated session with Supabase's Auth service.\n\nA session contains the tokens and metadata necessary for authenticating \nsubsequent API requests. It is returned after a successful sign-in or sign-up operation\nand can be refreshed using `Supabase.Auth.refresh_session/2`.","ref":"Supabase.Auth.Session.html"},{"type":"module","title":"Fields - Supabase.Auth.Session","doc":"* `access_token` - JWT token used for API authorization (required)\n* `refresh_token` - Token used to obtain a new access token when it expires (required)\n* `expires_in` - Number of seconds until the access token expires (required)\n* `expires_at` - Unix timestamp (in seconds) when the token expires\n* `token_type` - Type of token, usually \"bearer\" (required)\n* `provider_token` - OAuth provider-specific token (if applicable)\n* `provider_refresh_token` - OAuth provider-specific refresh token (if applicable)\n* `user` - The authenticated user's profile information (`Supabase.Auth.User`)","ref":"Supabase.Auth.Session.html#module-fields"},{"type":"module","title":"Usage - Supabase.Auth.Session","doc":"```elixir\n# Store the session securely after sign-in\n{:ok, session} = Supabase.Auth.sign_in_with_password(client, credentials)\n\n# Use the session for authenticated requests\n{:ok, user} = Supabase.Auth.get_user(client, session)\n\n# Refresh the session before it expires\n{:ok, refreshed_session} = Supabase.Auth.refresh_session(client, session.refresh_token)\n```","ref":"Supabase.Auth.Session.html#module-usage"},{"type":"module","title":"Security Notes - Supabase.Auth.Session","doc":"* The access_token contains sensitive information and should be secured appropriately\n* Sessions should be refreshed before they expire to maintain authentication\n* For web applications, it's recommended to store session tokens in HTTP-only cookies","ref":"Supabase.Auth.Session.html#module-security-notes"},{"type":"function","title":"Supabase.Auth.Session.parse/1","doc":"","ref":"Supabase.Auth.Session.html#parse/1"},{"type":"type","title":"Supabase.Auth.Session.t/0","doc":"","ref":"Supabase.Auth.Session.html#t:t/0"},{"type":"module","title":"Supabase.Auth.SessionFixture","doc":"This module is used to generate a session fixture for testing.","ref":"Supabase.Auth.SessionFixture.html"},{"type":"function","title":"Supabase.Auth.SessionFixture.session_fixture/1","doc":"","ref":"Supabase.Auth.SessionFixture.html#session_fixture/1"},{"type":"function","title":"Supabase.Auth.SessionFixture.session_fixture_json/1","doc":"","ref":"Supabase.Auth.SessionFixture.html#session_fixture_json/1"},{"type":"module","title":"Supabase.Auth.User","doc":"Represents a user profile in the Supabase authentication system.\n\nThis schema contains all the user information stored in the Auth service, including\nauthentication details, profile data, and linked identities. The User struct is typically\naccessed through `Supabase.Auth.get_user/2` after a successful authentication.","ref":"Supabase.Auth.User.html"},{"type":"module","title":"Important Fields - Supabase.Auth.User","doc":"* `id` - Unique identifier (UUID) for the user\n* `email` - User's email address (if applicable)\n* `phone` - User's phone number (if applicable)\n* `user_metadata` - Custom user attributes, editable by the user\n* `app_metadata` - Application-controlled attributes, not editable by the user\n* `created_at` - Timestamp when the user was created\n* `last_sign_in_at` - Timestamp of the user's most recent sign-in\n* `confirmed_at` - Timestamp when the user was confirmed (email verification)\n* `factors` - Multi-factor authentication methods associated with the user\n* `identities` - External identity providers linked to this user (GitHub, Google, etc.)\n* `is_anonymous` - Set to true if user is authenticated as anonymous","ref":"Supabase.Auth.User.html#module-important-fields"},{"type":"module","title":"Confirmation Status - Supabase.Auth.User","doc":"A user's verification status for email and phone can be determined using the following fields:\n\n* `email_confirmed_at` - Non-nil when email is verified\n* `phone_confirmed_at` - Non-nil when phone is verified","ref":"Supabase.Auth.User.html#module-confirmation-status"},{"type":"module","title":"Example Usage - Supabase.Auth.User","doc":"```elixir\n# Retrieve user details from a session\n{:ok, user} = Supabase.Auth.get_user(client, session)\n\n# Check if email is verified\nemail_verified = user.email_confirmed_at != nil\n\n# Access custom user metadata\nprofile_pic = user.user_metadata[\"avatar_url\"]\n```","ref":"Supabase.Auth.User.html#module-example-usage"},{"type":"module","title":"Related Schemas - Supabase.Auth.User","doc":"* `Supabase.Auth.User.Factor` - MFA factors associated with the user\n* `Supabase.Auth.User.Identity` - External identity providers linked to the user","ref":"Supabase.Auth.User.html#module-related-schemas"},{"type":"function","title":"Supabase.Auth.User.changeset/2","doc":"","ref":"Supabase.Auth.User.html#changeset/2"},{"type":"function","title":"Supabase.Auth.User.multiple_changeset/2","doc":"","ref":"Supabase.Auth.User.html#multiple_changeset/2"},{"type":"function","title":"Supabase.Auth.User.parse/1","doc":"Parses and validates a map of user attributes into a User struct.\n\nThis function validates that all required fields are present and correctly formatted,\nreturning either a valid User struct or a changeset with validation errors.","ref":"Supabase.Auth.User.html#parse/1"},{"type":"function","title":"Parameters - Supabase.Auth.User.parse/1","doc":"* `attrs` - Map containing user attributes returned from the Auth API","ref":"Supabase.Auth.User.html#parse/1-parameters"},{"type":"function","title":"Returns - Supabase.Auth.User.parse/1","doc":"* `{:ok, user}` - Successfully parsed user\n* `{:error, changeset}` - Failed validation with error details","ref":"Supabase.Auth.User.html#parse/1-returns"},{"type":"function","title":"Examples - Supabase.Auth.User.parse/1","doc":"iex> attrs = %{\n    ...>   \"id\" => \"550e8400-e29b-41d4-a716-446655440000\",\n    ...>   \"email\" => \"user@example.com\",\n    ...>   \"app_metadata\" => %{},\n    ...>   \"user_metadata\" => %{\"name\" => \"Test User\"},\n    ...>   \"aud\" => \"authenticated\",\n    ...>   \"created_at\" => \"2023-01-01T00:00:00Z\"\n    ...> }\n    iex> {:ok, user} = Supabase.Auth.User.parse(attrs)\n    iex> user.email\n    \"user@example.com\"","ref":"Supabase.Auth.User.html#parse/1-examples"},{"type":"function","title":"Supabase.Auth.User.parse_list/1","doc":"Parses a list of user attribute maps into a list of User structs.\n\nThis function attempts to validate and parse each map in the provided list.\nIf all validations succeed, it returns a list of User structs. If any \nvalidation fails, it returns the first error encountered.","ref":"Supabase.Auth.User.html#parse_list/1"},{"type":"function","title":"Parameters - Supabase.Auth.User.parse_list/1","doc":"* `list_attrs` - List of maps containing user attributes","ref":"Supabase.Auth.User.html#parse_list/1-parameters"},{"type":"function","title":"Returns - Supabase.Auth.User.parse_list/1","doc":"* `{:ok, [user, ...]}` - Successfully parsed list of users\n* `{:error, changeset}` - First validation error encountered","ref":"Supabase.Auth.User.html#parse_list/1-returns"},{"type":"function","title":"Examples - Supabase.Auth.User.parse_list/1","doc":"iex> attrs_list = [\n    ...>   %{\"id\" => \"user1\", \"app_metadata\" => %{}, \"aud\" => \"auth\", \"created_at\" => \"2023-01-01T00:00:00Z\"},\n    ...>   %{\"id\" => \"user2\", \"app_metadata\" => %{}, \"aud\" => \"auth\", \"created_at\" => \"2023-01-01T00:00:00Z\"}\n    ...> ]\n    iex> {:ok, users} = Supabase.Auth.User.parse_list(attrs_list)\n    iex> length(users)\n    2","ref":"Supabase.Auth.User.html#parse_list/1-examples"},{"type":"type","title":"Supabase.Auth.User.t/0","doc":"","ref":"Supabase.Auth.User.html#t:t/0"},{"type":"module","title":"Supabase.Auth.User.Factor","doc":"This schema is used to validate and parse the parameters for a user factor.","ref":"Supabase.Auth.User.Factor.html"},{"type":"module","title":"Fields - Supabase.Auth.User.Factor","doc":"* `friendly_name` - The friendly name of the factor.\n  * `factor_type` - The type of factor.\n  * `status` - The status of the factor.\n  * `created_at` - The creation date of the factor.\n  * `updated_at` - The last update date of the factor.\n  * `id` - The factor's ID.","ref":"Supabase.Auth.User.Factor.html#module-fields"},{"type":"function","title":"Supabase.Auth.User.Factor.changeset/2","doc":"","ref":"Supabase.Auth.User.Factor.html#changeset/2"},{"type":"type","title":"Supabase.Auth.User.Factor.t/0","doc":"","ref":"Supabase.Auth.User.Factor.html#t:t/0"},{"type":"module","title":"Supabase.Auth.User.Identity","doc":"This schema is used to validate and parse the identity of a user.","ref":"Supabase.Auth.User.Identity.html"},{"type":"module","title":"Fields - Supabase.Auth.User.Identity","doc":"* `id` - The user's ID.\n  * `user_id` - The user's ID.\n  * `provider` - The user's provider.\n  * `created_at` - The user's creation date.\n  * `updated_at` - The user's last update date.\n  * `identity_data` - The user's identity data.\n  * `last_sign_in_at` - The user's last sign-in date.","ref":"Supabase.Auth.User.Identity.html#module-fields"},{"type":"function","title":"Supabase.Auth.User.Identity.changeset/2","doc":"","ref":"Supabase.Auth.User.Identity.html#changeset/2"},{"type":"function","title":"Supabase.Auth.User.Identity.parse/1","doc":"","ref":"Supabase.Auth.User.Identity.html#parse/1"},{"type":"function","title":"Supabase.Auth.User.Identity.parse_list/1","doc":"","ref":"Supabase.Auth.User.Identity.html#parse_list/1"},{"type":"function","title":"Supabase.Auth.User.Identity.providers/0","doc":"","ref":"Supabase.Auth.User.Identity.html#providers/0"},{"type":"type","title":"Supabase.Auth.User.Identity.providers/0","doc":"","ref":"Supabase.Auth.User.Identity.html#t:providers/0"},{"type":"type","title":"Supabase.Auth.User.Identity.t/0","doc":"","ref":"Supabase.Auth.User.Identity.html#t:t/0"},{"type":"module","title":"Supabase.Auth.UserFixture","doc":"This module is used to generate fixtures for the `Supabase.Auth.User` schema.","ref":"Supabase.Auth.UserFixture.html"},{"type":"function","title":"Supabase.Auth.UserFixture.user_fixture/1","doc":"Generate a user fixture.","ref":"Supabase.Auth.UserFixture.html#user_fixture/1"},{"type":"function","title":"Supabase.Auth.UserFixture.user_fixture_json/1","doc":"","ref":"Supabase.Auth.UserFixture.html#user_fixture_json/1"},{"type":"module","title":"Supabase.GoTrue","doc":"","ref":"Supabase.GoTrue.html"},{"type":"function","title":"Supabase.GoTrue.exchange_code_for_session/4","doc":"See  Supabase.Auth.exchange_code_for_session/4 .","ref":"Supabase.GoTrue.html#exchange_code_for_session/4"},{"type":"function","title":"Supabase.GoTrue.get_server_health/1","doc":"See  Supabase.Auth.get_server_health/1 .","ref":"Supabase.GoTrue.html#get_server_health/1"},{"type":"function","title":"Supabase.GoTrue.get_server_settings/1","doc":"See  Supabase.Auth.get_server_settings/1 .","ref":"Supabase.GoTrue.html#get_server_settings/1"},{"type":"function","title":"Supabase.GoTrue.get_user/2","doc":"See  Supabase.Auth.get_user/2 .","ref":"Supabase.GoTrue.html#get_user/2"},{"type":"function","title":"Supabase.GoTrue.get_user_identities/2","doc":"See  Supabase.Auth.get_user_identities/2 .","ref":"Supabase.GoTrue.html#get_user_identities/2"},{"type":"function","title":"Supabase.GoTrue.link_identity/3","doc":"See  Supabase.Auth.link_identity/3 .","ref":"Supabase.GoTrue.html#link_identity/3"},{"type":"function","title":"Supabase.GoTrue.reauthenticate/2","doc":"See  Supabase.Auth.reauthenticate/2 .","ref":"Supabase.GoTrue.html#reauthenticate/2"},{"type":"function","title":"Supabase.GoTrue.refresh_session/2","doc":"See  Supabase.Auth.refresh_session/2 .","ref":"Supabase.GoTrue.html#refresh_session/2"},{"type":"function","title":"Supabase.GoTrue.resend/3","doc":"See  Supabase.Auth.resend/3 .","ref":"Supabase.GoTrue.html#resend/3"},{"type":"function","title":"Supabase.GoTrue.reset_password_for_email/3","doc":"See  Supabase.Auth.reset_password_for_email/3 .","ref":"Supabase.GoTrue.html#reset_password_for_email/3"},{"type":"function","title":"Supabase.GoTrue.sign_in_anonymously/2","doc":"See  Supabase.Auth.sign_in_anonymously/2 .","ref":"Supabase.GoTrue.html#sign_in_anonymously/2"},{"type":"function","title":"Supabase.GoTrue.sign_in_with_id_token/2","doc":"See  Supabase.Auth.sign_in_with_id_token/2 .","ref":"Supabase.GoTrue.html#sign_in_with_id_token/2"},{"type":"function","title":"Supabase.GoTrue.sign_in_with_oauth/2","doc":"See  Supabase.Auth.sign_in_with_oauth/2 .","ref":"Supabase.GoTrue.html#sign_in_with_oauth/2"},{"type":"function","title":"Supabase.GoTrue.sign_in_with_otp/2","doc":"See  Supabase.Auth.sign_in_with_otp/2 .","ref":"Supabase.GoTrue.html#sign_in_with_otp/2"},{"type":"function","title":"Supabase.GoTrue.sign_in_with_password/2","doc":"See  Supabase.Auth.sign_in_with_password/2 .","ref":"Supabase.GoTrue.html#sign_in_with_password/2"},{"type":"function","title":"Supabase.GoTrue.sign_in_with_sso/2","doc":"See  Supabase.Auth.sign_in_with_sso/2 .","ref":"Supabase.GoTrue.html#sign_in_with_sso/2"},{"type":"function","title":"Supabase.GoTrue.sign_up/2","doc":"See  Supabase.Auth.sign_up/2 .","ref":"Supabase.GoTrue.html#sign_up/2"},{"type":"function","title":"Supabase.GoTrue.unlink_identity/3","doc":"See  Supabase.Auth.unlink_identity/3 .","ref":"Supabase.GoTrue.html#unlink_identity/3"},{"type":"function","title":"Supabase.GoTrue.update_user/3","doc":"See  Supabase.Auth.update_user/3 .","ref":"Supabase.GoTrue.html#update_user/3"},{"type":"function","title":"Supabase.GoTrue.verify_otp/2","doc":"See  Supabase.Auth.verify_otp/2 .","ref":"Supabase.GoTrue.html#verify_otp/2"},{"type":"extras","title":"Supabase Auth","doc":"# Supabase Auth\n\n[![hex.pm](https://img.shields.io/hexpm/v/supabase_auth.svg)](https://hex.pm/packages/supabase_auth)\n[![docs](https://img.shields.io/badge/hex-docs-blue.svg)](https://hexdocs.pm/supabase_auth)\n[![ci](https://github.com/supabase-community/auth-ex/actions/workflows/ci.yml/badge.svg)](https://github.com/supabase-community/auth-ex/actions/workflows/ci.yml)\n\n[Auth](https://supabase.com/docs/guides/auth) implementation for the [Supabase Potion](https://hexdocs.pm/supabase_potion) SDK in Elixir.","ref":"readme.html"},{"type":"extras","title":"Installation - Supabase Auth","doc":"```elixir\ndef deps do\n  [\n    {:supabase_potion, \"~> 0.6\"},\n    {:supabase_auth, \"~> 0.6.2\"} # x-release-please-version\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Quick Start - Supabase Auth","doc":"1. Configure your Supabase client in `config.exs`:\n\n```elixir\nimport Config\n\nconfig :my_app, MyApp.Supabase.Client,\n  base_url: \"https://myapp.supabase.co\",\n  api_key: \"myapp-api-key\"\n\nconfig :supabase_auth, auth_module: MyAppWeb.Auth\n```\n\n2. Create your Supabase client:\n\n```elixir\ndefmodule MyApp.Supabase.Client do\n  use Supabase.Client, otp_app: :my_app\nend\n```\n\n3. Use the authentication functions:\n\n```elixir\n# Sign in with email and password\n{:ok, session} = Supabase.Auth.sign_in_with_password(client, %{\n  email: \"user@example.com\",\n  password: \"secure-password\"\n})\n\n# Get the current user\n{:ok, user} = Supabase.Auth.get_user(client, session)\n```","ref":"readme.html#quick-start"},{"type":"extras","title":"Documentation - Supabase Auth","doc":"- [HexDocs](https://hexdocs.pm/supabase_auth) - Complete API reference\n- [Authentication Guide](https://hexdocs.pm/supabase_auth/auth_guide.html) - Authentication methods and integration\n- [MFA Guide](https://hexdocs.pm/supabase_auth/mfa_guide.html) - Multi-Factor Authentication","ref":"readme.html#documentation"},{"type":"extras","title":"Authentication Methods - Supabase Auth","doc":"- Sign in with email/password\n- Sign in with phone/password\n- Sign in with magic link (OTP)\n- OAuth (social) authentication\n- Single Sign-On (SSO)\n- Anonymous sign in\n- Multi-factor authentication","ref":"readme.html#authentication-methods"},{"type":"extras","title":"Integration Options - Supabase Auth","doc":"","ref":"readme.html#integration-options"},{"type":"extras","title":"Traditional Web Applications (Plug/Phoenix) - Supabase Auth","doc":"```elixir\n# Define your auth module\ndefmodule MyAppWeb.Auth do\n  use Supabase.Auth.Plug,\n    client: MyApp.Supabase.Client,\n    endpoint: MyAppWeb.Endpoint,\n    signed_in_path: \"/app\",\n    not_authenticated_path: \"/login\"\nend\n\n# In your router\ndefmodule MyAppWeb.Router do\n  import MyAppWeb.Auth\n  \n  pipeline :browser do\n    plug :fetch_current_user\n  end\n  \n  # Public routes\n  scope \"/\", MyAppWeb do\n    pipe_through [:browser, :redirect_if_user_is_authenticated]\n    \n    get \"/login\", SessionController, :new\n    post \"/login\", SessionController, :create\n  end\n  \n  # Protected routes\n  scope \"/app\", MyAppWeb do\n    pipe_through [:browser, :require_authenticated_user]\n    \n    get \"/\", DashboardController, :index\n  end\nend\n```","ref":"readme.html#traditional-web-applications-plug-phoenix"},{"type":"extras","title":"Phoenix LiveView Applications - Supabase Auth","doc":"```elixir\n# Define your auth module\ndefmodule MyAppWeb.Auth do\n  use Supabase.Auth.LiveView,\n    client: MyApp.Supabase.Client,\n    endpoint: MyAppWeb.Endpoint,\n    signed_in_path: \"/app\",\n    not_authenticated_path: \"/login\"\nend\n\n# In your LiveView\ndefmodule MyAppWeb.DashboardLive do\n  use MyAppWeb, :live_view\n  \n  on_mount {MyAppWeb.Auth, :mount_current_user}\n  on_mount {MyAppWeb.Auth, :ensure_authenticated}\n  \n  def mount(_params, _session, socket) do\n    # socket.assigns.current_user is available here\n    {:ok, assign(socket, page_title: \"Dashboard\")}\n  end\nend\n\n# In your router\nlive_session :authenticated,\n  on_mount: [\n    {MyAppWeb.Auth, :mount_current_user},\n    {MyAppWeb.Auth, :ensure_authenticated}\n  ] do\n  live \"/dashboard\", DashboardLive\nend\n```","ref":"readme.html#phoenix-liveview-applications"},{"type":"extras","title":"Examples - Supabase Auth","doc":"Check the [Supabase Potion examples showcase](https://github.com/supabase-community/supabase-ex?tab=readme-ov-file#examples) for sample applications.","ref":"readme.html#examples"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\n## [0.6.2](https://github.com/supabase-community/auth-ex/compare/v0.6.1...v0.6.2) (2025-07-20)\n\n* gen auth task templates ([#51](https://github.com/supabase-community/auth-ex/issues/51)) ([6e86c5f](https://github.com/supabase-community/auth-ex/commit/6e86c5f09784fc99be2891640997e388f37c0fe5))\n\n## [0.6.1](https://github.com/supabase-community/auth-ex/compare/v0.6.0...v0.6.1) (2025-07-20)","ref":"changelog.html"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* allows compilation when phoenix isn't present and only plug exists ([#46](https://github.com/supabase-community/auth-ex/issues/46)) ([5634705](https://github.com/supabase-community/auth-ex/commit/5634705db7aeb702fd1e130f4e2dafeaa030bad4))\n\n## [0.6.0](https://github.com/supabase-community/auth-ex/compare/v0.5.2...v0.6.0) (2025-07-15)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* cond compile mod/funs that depens on optional dependencies ([#45](https://github.com/supabase-community/auth-ex/issues/45)) ([840279b](https://github.com/supabase-community/auth-ex/commit/840279b2cfd47e5b2e6b5d5c1091c9c993c5c805))","ref":"changelog.html#bug-fixes-1"},{"type":"extras","title":"Code Refactoring - Changelog","doc":"* rename package to supabase_auth ([#43](https://github.com/supabase-community/auth-ex/issues/43)) ([eb220d1](https://github.com/supabase-community/auth-ex/commit/eb220d1c0144ed3c8ee0bb61088282289675114b))\n\n## [0.5.2] - 2025-06-10","ref":"changelog.html#code-refactoring"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed `sign_in_with_oauth` result format to include flow_type, provider, and URL\n- Added anonymous user support with `is_anonymous` field in User schema\n- Fixed captcha token handling for anonymous users\n\n## [0.5.1] - 2025-05-20","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Correctly hadnle single strategy on mix task generator\n\n## [0.5.0] - 2025-05-18","ref":"changelog.html#fixed-1"},{"type":"extras","title":"Added - Changelog","doc":"- Implemented auto-refresh token functionality for managing token expiration\n- Added reauthentication functionality for sensitive operations\n- Enhanced PKCE flow with `exchange_code_for_session` implementation\n- Added authentication function generator task for Phoenix applications\n- Improved documentation for schema modules including proper typespecs","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Resolved documentation warnings when referenced hidden schema modules\n- Fixed compatibility issues with latest Phoenix versions\n- Corrected session management in LiveView integration","ref":"changelog.html#fixed-2"},{"type":"extras","title":"Improved - Changelog","doc":"- Streamlined README with better getting started instructions\n- Enhanced module documentation for better developer experience\n- Improved schema validation and error handling\n- Better integration with LSP for enhanced developer tooling\n- Updated validation patterns for authentication parameters\n\n## [0.4.1] - 2025-02-17","ref":"changelog.html#improved"},{"type":"extras","title":"Added - Changelog","doc":"- Added new server monitoring functions:\n  - `get_server_health/1` to check Auth server health status\n  - `get_server_settings/2` to retrieve server configuration\n- Implemented `refresh_session/2` for token refresh functionality\n- Added `sign_in_anonymously/2` for anonymous authentication\n- Added comprehensive unit tests for the public API","ref":"changelog.html#added-1"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed pagination issues in admin user listing\n- Fixed update user functionality in admin API\n- Corrected JSON response handling in admin API endpoints\n- Resolved authentication path issues when ensuring user authentication","ref":"changelog.html#fixed-3"},{"type":"extras","title":"Improved - Changelog","doc":"- Improved integration with base Supabase SDK\n- Enhanced documentation and usage examples\n- Better integration between Plug and LiveView components\n- Refined error handling for authentication flows\n- Improved client module customization options","ref":"changelog.html#improved-1"},{"type":"extras","title":"Internal - Changelog","doc":"- Updated dependency on supabase_potion to latest version\n- Upgraded minimum Elixir version requirement\n- Enhanced test coverage across authentication flows\n- Refactored code for better maintainability\n\n## [0.4.0] - 2025-01-15","ref":"changelog.html#internal"},{"type":"extras","title":"Added - Changelog","doc":"- Implemented PKCE authentication flow\n- Added support for OAuth2 authentication\n- Integrated advanced session management\n- Added support for custom authentication handlers","ref":"changelog.html#added-2"},{"type":"extras","title":"Changed - Changelog","doc":"- Improved error handling mechanisms\n- Enhanced LiveView integration\n- Updated authentication flow documentation\n\n## [0.3.10] - 2024-12-20","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Support for custom client modules\n- Enhanced plug integration capabilities","ref":"changelog.html#added-3"},{"type":"extras","title":"Fixed - Changelog","doc":"- Issue with reusing already started clients\n- Authentication path resolution problems\n\n## [0.3.9] - 2024-12-10","ref":"changelog.html#fixed-4"},{"type":"extras","title":"Added - Changelog","doc":"- Resend signup email functionality\n- Password reset capabilities","ref":"changelog.html#added-4"},{"type":"extras","title":"Fixed - Changelog","doc":"- Access token usage in admin API\n- JSON response parsing in admin endpoints\n\n## [0.3.8] - 2024-11-25","ref":"changelog.html#fixed-5"},{"type":"extras","title":"Added - Changelog","doc":"- User update functionality\n- Enhanced admin API capabilities","ref":"changelog.html#added-5"},{"type":"extras","title":"Fixed - Changelog","doc":"- Authentication path redirection issues\n- Session management improvements\n\n## [0.3.7] - 2024-11-10","ref":"changelog.html#fixed-6"},{"type":"extras","title":"Added - Changelog","doc":"- LiveView integration improvements\n- Enhanced plug-based authentication","ref":"changelog.html#added-6"},{"type":"extras","title":"Changed - Changelog","doc":"- Upgraded minimum Elixir version requirements\n- Refined authentication flow handling\n\n## [0.3.6] - 2024-10-25","ref":"changelog.html#changed-1"},{"type":"extras","title":"Added - Changelog","doc":"- Multiple sign-in method support\n- Pagination for user listing","ref":"changelog.html#added-7"},{"type":"extras","title":"Fixed - Changelog","doc":"- User update issues in admin API\n- Authentication flow edge cases\n\n## [0.3.5] - 2024-10-10","ref":"changelog.html#fixed-7"},{"type":"extras","title":"Added - Changelog","doc":"- SSO authentication support\n- Enhanced session management","ref":"changelog.html#added-8"},{"type":"extras","title":"Fixed - Changelog","doc":"- Authentication token handling\n- Session persistence issues\n\n## [0.3.4] - 2024-09-25","ref":"changelog.html#fixed-8"},{"type":"extras","title":"Added - Changelog","doc":"- OTP authentication support\n- Improved error handling","ref":"changelog.html#added-9"},{"type":"extras","title":"Changed - Changelog","doc":"- Enhanced documentation\n- Refined authentication flows\n\n## [0.3.3] - 2024-09-10","ref":"changelog.html#changed-2"},{"type":"extras","title":"Added - Changelog","doc":"- Custom authentication handlers\n- Enhanced session management","ref":"changelog.html#added-10"},{"type":"extras","title":"Fixed - Changelog","doc":"- Authentication flow issues\n- Token management improvements\n\n## [0.3.2] - 2024-08-25","ref":"changelog.html#fixed-9"},{"type":"extras","title":"Added - Changelog","doc":"- LiveView authentication hooks\n- Enhanced plug integration","ref":"changelog.html#added-11"},{"type":"extras","title":"Fixed - Changelog","doc":"- Session management issues\n- Authentication path handling\n\n## [0.3.1] - 2024-08-10","ref":"changelog.html#fixed-10"},{"type":"extras","title":"Added - Changelog","doc":"- Basic LiveView support\n- Initial plug integration","ref":"changelog.html#added-12"},{"type":"extras","title":"Fixed - Changelog","doc":"- Authentication flow issues\n- Token handling improvements\n\n## [0.3.0] - 2024-07-25","ref":"changelog.html#fixed-11"},{"type":"extras","title":"Added - Changelog","doc":"- Initial LiveView integration\n- Basic plug support\n- Core authentication flows\n- Session management","ref":"changelog.html#added-13"},{"type":"extras","title":"Changed - Changelog","doc":"- Major refactoring of authentication handling\n- Improved documentation structure\n- Enhanced error handling\n\n## [0.2.1] - 2024-07-10","ref":"changelog.html#changed-3"},{"type":"extras","title":"Fixed - Changelog","doc":"- Authentication token handling\n- Session management issues\n- Documentation improvements\n\n## [0.2.0] - 2024-06-25","ref":"changelog.html#fixed-12"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release\n- Basic authentication functionality\n- User management capabilities\n- Session handling\n- Basic documentation","ref":"changelog.html#added-14"},{"type":"extras","title":"Changed - Changelog","doc":"- Core authentication structure\n- Initial API design\n- Basic error handling","ref":"changelog.html#changed-4"},{"type":"extras","title":"Authentication with Supabase Auth in Elixir","doc":"# Authentication with Supabase Auth in Elixir\n\nThis guide covers how to use Supabase's authentication service (Auth) with your Elixir applications. It provides examples for the most common authentication scenarios and explains how to integrate authentication with both traditional Phoenix applications and LiveView.","ref":"auth_guide.html"},{"type":"extras","title":"Authentication Methods - Authentication with Supabase Auth in Elixir","doc":"Supabase Auth supports multiple authentication methods:","ref":"auth_guide.html#authentication-methods"},{"type":"extras","title":"Email and Password Authentication - Authentication with Supabase Auth in Elixir","doc":"The most common authentication method is email+password sign-in:\n\n```elixir\n# Sign in with email and password\n{:ok, session} = Supabase.Auth.sign_in_with_password(client, %{\n  email: \"user@example.com\",\n  password: \"securepassword\"\n})\n\n# Use the session to get the current user\n{:ok, user} = Supabase.Auth.get_user(client, session)\n```","ref":"auth_guide.html#email-and-password-authentication"},{"type":"extras","title":"Phone Authentication - Authentication with Supabase Auth in Elixir","doc":"Phone-based authentication using SMS verification:\n\n```elixir\n# Sign in with phone and password\n{:ok, session} = Supabase.Auth.sign_in_with_password(client, %{\n  phone: \"+15555551234\",\n  password: \"securepassword\"\n})\n```","ref":"auth_guide.html#phone-authentication"},{"type":"extras","title":"One-Time Password (OTP) - Authentication with Supabase Auth in Elixir","doc":"OTP is a passwordless authentication method that sends a temporary code to the user's email or phone:\n\n```elixir\n# Request an OTP to be sent\n:ok = Supabase.Auth.sign_in_with_otp(client, %{\n  email: \"user@example.com\"\n})\n\n# Later, verify the OTP to get a session\n{:ok, session} = Supabase.Auth.verify_otp(client, %{\n  email: \"user@example.com\",\n  token: \"123456\",\n  type: \"email\"\n})\n```","ref":"auth_guide.html#one-time-password-otp"},{"type":"extras","title":"OAuth (Social Authentication) - Authentication with Supabase Auth in Elixir","doc":"Sign in with social providers like Google, GitHub, etc.:\n\n```elixir\n# Get the OAuth URL to redirect the user to\n{:ok, provider, redirect_url} = Supabase.Auth.sign_in_with_oauth(client, %{\n  provider: :github,\n  redirect_to: \"https://myapp.com/auth/callback\"\n})\n\n# After OAuth callback, exchange the code for a session\n{:ok, session} = Supabase.Auth.exchange_code_for_session(client, auth_code, code_verifier)\n```","ref":"auth_guide.html#oauth-social-authentication"},{"type":"extras","title":"Single Sign-On (SSO) - Authentication with Supabase Auth in Elixir","doc":"Enterprise single sign-on for organizations:\n\n```elixir\n# Start SSO authentication\n{:ok, redirect_url} = Supabase.Auth.sign_in_with_sso(client, %{\n  domain: \"example.org\",\n  redirect_to: \"https://myapp.com/auth/callback\"\n})\n```","ref":"auth_guide.html#single-sign-on-sso"},{"type":"extras","title":"Anonymous Authentication - Authentication with Supabase Auth in Elixir","doc":"Create a session without user credentials:\n\n```elixir\n{:ok, session} = Supabase.Auth.sign_in_anonymously(client)\n```","ref":"auth_guide.html#anonymous-authentication"},{"type":"extras","title":"Session Management - Authentication with Supabase Auth in Elixir","doc":"A successful authentication returns a `Session` struct containing tokens and user information:\n\n```elixir\n%Supabase.Auth.Session{\n  access_token: \"eyJhbGciOiJ...\",\n  refresh_token: \"kIvYW5...\",\n  expires_in: 3600,\n  expires_at: 1650123456, # Unix timestamp when token expires\n  token_type: \"bearer\",\n  user: %Supabase.Auth.User{...}\n}\n```","ref":"auth_guide.html#session-management"},{"type":"extras","title":"Refreshing Sessions - Authentication with Supabase Auth in Elixir","doc":"To keep users logged in, refresh the session before the access token expires:\n\n```elixir\n{:ok, new_session} = Supabase.Auth.refresh_session(client, session.refresh_token)\n```\n\nFor automatic token refreshing, you can use the `Supabase.Auth.AutoRefresh` GenServer in your supervision tree:\n\n```elixir\n# In your application.ex:\nchildren = [\n  {Supabase.Auth.AutoRefresh, {client, session, refresh_callback_fn}}\n]\n```","ref":"auth_guide.html#refreshing-sessions"},{"type":"extras","title":"User Management - Authentication with Supabase Auth in Elixir","doc":"","ref":"auth_guide.html#user-management"},{"type":"extras","title":"User Registration - Authentication with Supabase Auth in Elixir","doc":"Create a new user with email and password:\n\n```elixir\n{:ok, user} = Supabase.Auth.sign_up(client, %{\n  email: \"new_user@example.com\",\n  password: \"securepassword\"\n})\n```","ref":"auth_guide.html#user-registration"},{"type":"extras","title":"Getting User Information - Authentication with Supabase Auth in Elixir","doc":"Retrieve current user details:\n\n```elixir\n{:ok, user} = Supabase.Auth.get_user(client, session)\n```","ref":"auth_guide.html#getting-user-information"},{"type":"extras","title":"Updating User Information - Authentication with Supabase Auth in Elixir","doc":"Update user profile details:\n\n```elixir\n{:ok, updated_conn} = Supabase.Auth.update_user(client, conn, %{\n  data: %{\n    display_name: \"Jane Doe\",\n    avatar_url: \"https://example.com/avatar.png\"\n  }\n})\n```","ref":"auth_guide.html#updating-user-information"},{"type":"extras","title":"Password Recovery - Authentication with Supabase Auth in Elixir","doc":"Send a password reset email:\n\n```elixir\n:ok = Supabase.Auth.reset_password_for_email(client, \n  \"user@example.com\", \n  redirect_to: \"https://myapp.com/reset-password\"\n)\n```","ref":"auth_guide.html#password-recovery"},{"type":"extras","title":"Multi-factor Authentication (MFA) - Authentication with Supabase Auth in Elixir","doc":"Auth supports multi-factor authentication for additional security:","ref":"auth_guide.html#multi-factor-authentication-mfa"},{"type":"extras","title":"Managing MFA Factors - Authentication with Supabase Auth in Elixir","doc":"```elixir\n# Get user's MFA factors\n{:ok, user} = Supabase.Auth.get_user(client, session)\nfactors = user.factors\n\n# Check if user has MFA enabled\nhas_mfa = length(factors) > 0\n```","ref":"auth_guide.html#managing-mfa-factors"},{"type":"extras","title":"Identity Management - Authentication with Supabase Auth in Elixir","doc":"Auth allows users to link multiple authentication methods to a single account:","ref":"auth_guide.html#identity-management"},{"type":"extras","title":"Linking New Identity Providers - Authentication with Supabase Auth in Elixir","doc":"```elixir\n# Get a URL to link a new provider\n{:ok, %{provider: :github, url: redirect_url}} = Supabase.Auth.link_identity(\n  client, \n  session, \n  %{provider: :github}\n)\n\n# Redirect user to this URL to link their GitHub account\n```","ref":"auth_guide.html#linking-new-identity-providers"},{"type":"extras","title":"Unlinking Providers - Authentication with Supabase Auth in Elixir","doc":"```elixir\n# Remove a linked identity\n:ok = Supabase.Auth.unlink_identity(client, session, identity_id)\n```","ref":"auth_guide.html#unlinking-providers"},{"type":"extras","title":"Listing Linked Identities - Authentication with Supabase Auth in Elixir","doc":"```elixir\n# Get all linked identities\n{:ok, identities} = Supabase.Auth.get_user_identities(client, session)\n```","ref":"auth_guide.html#listing-linked-identities"},{"type":"extras","title":"Server Information - Authentication with Supabase Auth in Elixir","doc":"Get information about the Auth server:\n\n```elixir\n# Get server settings\n{:ok, settings} = Supabase.Auth.get_server_settings(client)\n\n# Check server health\n{:ok, health} = Supabase.Auth.get_server_health(client)\n```","ref":"auth_guide.html#server-information"},{"type":"extras","title":"Integration with Phoenix - Authentication with Supabase Auth in Elixir","doc":"","ref":"auth_guide.html#integration-with-phoenix"},{"type":"extras","title":"Traditional Phoenix Applications - Authentication with Supabase Auth in Elixir","doc":"For Phoenix applications with traditional views, use the `Supabase.Auth.Plug` module:\n\n```elixir\n# lib/my_app_web/auth.ex\ndefmodule MyAppWeb.Auth do\n  use Supabase.Auth.Plug,\n    client: MyApp.Supabase.Client,\n    endpoint: MyAppWeb.Endpoint,\n    signed_in_path: \"/app\", \n    not_authenticated_path: \"/login\",\n    session_cookie: \"my_app_session\"\nend\n\n# lib/my_app_web/router.ex\ndefmodule MyAppWeb.Router do\n  import MyAppWeb.Auth\n  \n  pipeline :browser do\n    plug :fetch_current_user\n  end\n  \n  # Public routes\n  scope \"/\", MyAppWeb do\n    pipe_through [:browser, :redirect_if_user_is_authenticated]\n    \n    get \"/login\", SessionController, :new\n    post \"/login\", SessionController, :create\n  end\n  \n  # Protected routes\n  scope \"/app\", MyAppWeb do\n    pipe_through [:browser, :require_authenticated_user]\n    \n    get \"/\", DashboardController, :index\n  end\nend\n\n# lib/my_app_web/controllers/session_controller.ex\ndefmodule MyAppWeb.SessionController do\n  import MyAppWeb.Auth\n  \n  def create(conn, %{\"email\" => email, \"password\" => password}) do\n    case log_in_with_password(conn, %{email: email, password: password}) do\n      {:ok, conn} ->\n        conn\n        |> put_flash(:info, \"Welcome back!\")\n        |> redirect(to: Routes.dashboard_path(conn, :index))\n        \n      {:error, _reason} ->\n        conn\n        |> put_flash(:error, \"Invalid email/password\")\n        |> render(\"new.html\")\n    end\n  end\nend\n```","ref":"auth_guide.html#traditional-phoenix-applications"},{"type":"extras","title":"Phoenix LiveView Applications - Authentication with Supabase Auth in Elixir","doc":"For LiveView applications, use the `Supabase.Auth.LiveView` module:\n\n```elixir\n# lib/my_app_web/auth.ex\ndefmodule MyAppWeb.Auth do\n  use Supabase.Auth.LiveView,\n    client: MyApp.Supabase.Client,\n    endpoint: MyAppWeb.Endpoint,\n    signed_in_path: \"/app\",\n    not_authenticated_path: \"/login\"\nend\n\n# In your LiveView\ndefmodule MyAppWeb.DashboardLive do\n  use MyAppWeb, :live_view\n  \n  on_mount {MyAppWeb.Auth, :mount_current_user}\n  on_mount {MyAppWeb.Auth, :ensure_authenticated}\n  \n  def mount(_params, _session, socket) do\n    # socket.assigns.current_user is available here\n    {:ok, assign(socket, page_title: \"Dashboard\")}\n  end\nend\n\n# In your router\nlive_session :authenticated,\n  on_mount: [\n    {MyAppWeb.Auth, :mount_current_user},\n    {MyAppWeb.Auth, :ensure_authenticated}\n  ] do\n  live \"/dashboard\", DashboardLive\nend\n```","ref":"auth_guide.html#phoenix-liveview-applications"},{"type":"extras","title":"Best Practices - Authentication with Supabase Auth in Elixir","doc":"1. **Secure Token Storage**: Store tokens in HTTP-only cookies for web applications to prevent XSS attacks.\n\n2. **Token Refresh**: Implement token refresh before expiration to maintain continuous authentication.\n\n3. **Error Handling**: Properly handle authentication errors and provide feedback to users.\n\n4. **HTTPS**: Always use HTTPS in production to protect authentication data.\n\n5. **Rate Limiting**: Implement rate limiting for authentication endpoints to prevent brute force attacks.","ref":"auth_guide.html#best-practices"},{"type":"extras","title":"Conclusion - Authentication with Supabase Auth in Elixir","doc":"This guide covered the essentials of using Supabase's Auth authentication service with Elixir applications. For more detailed information on specific functions, refer to the module documentation.","ref":"auth_guide.html#conclusion"},{"type":"extras","title":"Multi-Factor Authentication (MFA) with Supabase Auth","doc":"# Multi-Factor Authentication (MFA) with Supabase Auth\n\nThis guide covers how to implement Multi-Factor Authentication (MFA) using Supabase's Auth authentication service in your Elixir applications.","ref":"mfa_guide.html"},{"type":"extras","title":"Understanding MFA in Supabase - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"Multi-Factor Authentication provides an additional security layer beyond passwords. Supabase supports several forms of MFA including:\n\n1. **Time-based One-Time Passwords (TOTP)**: Compatible with authenticator apps like Google Authenticator or Authy\n2. **SMS-based verification**: One-time codes sent via text message\n3. **Email-based verification**: One-time codes sent via email\n\nEach user can have multiple authentication factors associated with their account, represented by the `Supabase.Auth.User.Factor` struct.","ref":"mfa_guide.html#understanding-mfa-in-supabase"},{"type":"extras","title":"MFA Factor Management - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"","ref":"mfa_guide.html#mfa-factor-management"},{"type":"extras","title":"Viewing User Factors - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"To check if a user has MFA enabled and view their factors:\n\n```elixir\n# Get the current user\n{:ok, user} = Supabase.Auth.get_user(client, session)\n\n# Check for active factors\nhas_mfa_enabled = Enum.any?(user.factors || [], fn factor -> factor.status == \"verified\" end)\n\n# Get all factors\nfactors = user.factors || []\n```\n\nEach factor includes information such as:\n\n```elixir\n%Supabase.Auth.User.Factor{\n  id: \"f1d74b2c-9bb7-4c74-b9b9-44a48f261a48\",\n  type: \"totp\",\n  status: \"verified\",  # or \"unverified\"\n  friendly_name: \"Google Authenticator\",\n  factor_type: \"totp\",\n  created_at: ~N[2023-01-01 00:00:00],\n  updated_at: ~N[2023-01-01 00:00:00]\n}\n```","ref":"mfa_guide.html#viewing-user-factors"},{"type":"extras","title":"Working with Admin APIs - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"For admin operations on MFA factors, use the `Supabase.Auth.Admin` module:","ref":"mfa_guide.html#working-with-admin-apis"},{"type":"extras","title":"Enrolling a TOTP Factor (Admin) - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"```elixir\n{:ok, user_with_factors} = Supabase.Auth.Admin.enroll_factor(\n  client, \n  user_id, \n  %{type: \"totp\", friendly_name: \"My Authenticator App\"}\n)\n```\n\nThis returns a user object with a new unverified factor. The response also includes a QR code URL that should be displayed to the user for scanning with their authenticator app.","ref":"mfa_guide.html#enrolling-a-totp-factor-admin"},{"type":"extras","title":"Verifying a TOTP Factor (Admin) - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"After the user scans the QR code, they need to verify their factor by entering a code:\n\n```elixir\n{:ok, verified_factor} = Supabase.Auth.Admin.verify_factor(\n  client,\n  user_id,\n  factor_id,\n  %{challenge: \"123456\"}  # Code from authenticator app\n)\n```","ref":"mfa_guide.html#verifying-a-totp-factor-admin"},{"type":"extras","title":"Challenging a Factor (Admin) - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"When a user attempts to access a protected resource, you can challenge their MFA factor:\n\n```elixir\n{:ok, challenge} = Supabase.Auth.Admin.challenge_factor(\n  client,\n  user_id,\n  factor_id\n)\n```","ref":"mfa_guide.html#challenging-a-factor-admin"},{"type":"extras","title":"Unenrolling a Factor (Admin) - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"To remove an MFA factor:\n\n```elixir\n:ok = Supabase.Auth.Admin.delete_factor(client, user_id, factor_id)\n```","ref":"mfa_guide.html#unenrolling-a-factor-admin"},{"type":"extras","title":"Authenticator Assurance Levels (AAL) - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"Supabase uses Authenticator Assurance Levels (AAL) to determine the strength of authentication:\n\n- **AAL0**: No authentication\n- **AAL1**: Single-factor authentication (e.g., password only)\n- **AAL2**: Multi-factor authentication (password + MFA)\n\nYou can check the current AAL:\n\n```elixir\naal = user.app_metadata[\"aal\"]  # \"aal1\" or \"aal2\"\n```","ref":"mfa_guide.html#authenticator-assurance-levels-aal"},{"type":"extras","title":"Requiring MFA for Sensitive Operations - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"For sensitive operations like changing passwords or making payments, you can use the reauthentication function:\n\n```elixir\n# Request a reauthentication challenge\n:ok = Supabase.Auth.reauthenticate(client, session)\n\n# User completes verification with OTP\n{:ok, verified_session} = Supabase.Auth.verify_otp(\n  client, \n  %{\n    type: \"reauthentication\",\n    token: \"123456\"\n  }\n)\n\n# Now perform sensitive operation with the new verified session\n```","ref":"mfa_guide.html#requiring-mfa-for-sensitive-operations"},{"type":"extras","title":"MFA Integration with Phoenix - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"","ref":"mfa_guide.html#mfa-integration-with-phoenix"},{"type":"extras","title":"Enrollment Flow in Phoenix Controllers - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"```elixir\ndefmodule MyAppWeb.MFAController do\n  use MyAppWeb, :controller\n  \n  def new(conn, _params) do\n    user_id = conn.assigns.current_user.id\n    \n    # Create a new TOTP factor\n    {:ok, user_with_factor} = Supabase.Auth.Admin.enroll_factor(\n      MyApp.Supabase.Client.get(),\n      user_id,\n      %{type: \"totp\", friendly_name: \"Authenticator App\"}\n    )\n    \n    # Get the most recently created factor (the unverified one)\n    [new_factor | _] = Enum.sort_by(user_with_factor.factors, & &1.created_at, :desc)\n    \n    # Render the enrollment page with QR code URL\n    render(conn, \"new.html\", factor: new_factor, qr_code_url: new_factor.totp.qr_code)\n  end\n  \n  def verify(conn, %{\"code\" => code, \"factor_id\" => factor_id}) do\n    user_id = conn.assigns.current_user.id\n    \n    case Supabase.Auth.Admin.verify_factor(\n      MyApp.Supabase.Client.get(),\n      user_id,\n      factor_id,\n      %{challenge: code}\n    ) do\n      {:ok, _} ->\n        conn\n        |> put_flash(:info, \"MFA successfully enabled!\")\n        |> redirect(to: Routes.profile_path(conn, :show))\n        \n      {:error, _} ->\n        conn\n        |> put_flash(:error, \"Invalid verification code\")\n        |> redirect(to: Routes.mfa_path(conn, :new))\n    end\n  end\nend\n```","ref":"mfa_guide.html#enrollment-flow-in-phoenix-controllers"},{"type":"extras","title":"Verification Flow in LiveView - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"```elixir\ndefmodule MyAppWeb.MFALive do\n  use MyAppWeb, :live_view\n  \n  def mount(_params, session, socket) do\n    user_id = socket.assigns.current_user.id\n    \n    {:ok, challenge} = Supabase.Auth.Admin.challenge_factor(\n      MyApp.Supabase.Client.get(),\n      user_id,\n      socket.assigns.current_user.factors |> hd() |> Map.get(:id)\n    )\n    \n    {:ok, assign(socket, challenge_id: challenge.id, error: nil)}\n  end\n  \n  def handle_event(\"verify\", %{\"code\" => code}, socket) do\n    case Supabase.Auth.verify_challenge(\n      MyApp.Supabase.Client.get(),\n      socket.assigns.challenge_id,\n      %{code: code}\n    ) do\n      {:ok, new_session} ->\n        {:noreply, \n          socket\n          |> put_flash(:info, \"Verification successful!\")\n          |> push_redirect(to: ~p\"/dashboard\")}\n        \n      {:error, _} ->\n        {:noreply, assign(socket, error: \"Invalid verification code\")}\n    end\n  end\nend\n```","ref":"mfa_guide.html#verification-flow-in-liveview"},{"type":"extras","title":"Best Practices for MFA - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"1. **Backup Codes**: Provide users with backup codes in case they lose access to their MFA device.\n\n2. **Recovery Options**: Implement account recovery processes for users who lose all authentication factors.\n\n3. **Gradual Adoption**: Consider making MFA optional initially, then mandatory for specific user groups.\n\n4. **UX Considerations**: Clearly explain MFA benefits to users and make the setup process straightforward.\n\n5. **Security Logging**: Log all MFA-related activities for audit purposes.","ref":"mfa_guide.html#best-practices-for-mfa"},{"type":"extras","title":"Conclusion - Multi-Factor Authentication (MFA) with Supabase Auth","doc":"MFA significantly improves the security of your application by requiring multiple forms of verification. Supabase's Auth service makes it relatively straightforward to implement MFA in your Elixir applications.\n\nFor more detailed information, refer to the module documentation for the `Supabase.Auth.User.Factor` module and the `Supabase.Auth.Admin` module.","ref":"mfa_guide.html#conclusion"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}